import asyncio

from mini.apis import errors
from mini.apis.api_behavior import StartBehavior, ControlBehaviorResponse, StopBehavior
from mini.apis.api_expression import ControlMouthLamp, ControlMouthResponse
from mini.apis.api_expression import PlayExpression, PlayExpressionResponse
from mini.apis.api_expression import SetMouthLamp, SetMouthLampResponse, MouthLampColor, MouthLampMode
from mini.apis.base_api import MiniApiResultType
from mini.dns.dns_browser import WiFiDevice
from test.test_connect import test_connect, shutdown, test_start_run_program
from test.test_connect import test_get_device_by_name


# 测试让眼睛演示个表情
async def test_play_expression():
    """测试播放表情

    让机器人播放一个名为"codemao1"的内置表情，并等待回复结果

    #PlayExpressionResponse.isSuccess : 是否成功

    #PlayExpressionResponse.resultCode : 返回码

    """
    block: PlayExpression = PlayExpression(express_name="codemao1")
    # response: PlayExpressionResponse
    (resultType, response) = await block.execute()

    print(f'test_play_expression result: {response}')

    assert resultType == MiniApiResultType.Success, 'test_play_expression timetout'
    assert response is not None and isinstance(response,
                                               PlayExpressionResponse), 'test_play_expression result unavailable'
    assert response.isSuccess, 'play_expression failed'


# 测试, 让机器人跳舞/停止跳舞
async def test_control_behavior():
    """测试控制表现力

    让机器人开始跳一个名为"dance_0004"的舞蹈，并等待回复结果

    """
    # control_type: START, STOP
    block: StartBehavior = StartBehavior(name="dance_0004")
    # response ControlBehaviorResponse
    (resultType, response) = await block.execute()

    print(f'test_control_behavior result: {response}')
    print(
        'resultCode = {0}, error = {1}'.format(response.resultCode, errors.get_express_error_str(response.resultCode)))

    assert resultType == MiniApiResultType.Success, 'test_control_behavior timetout'
    assert response is not None and isinstance(response,
                                               ControlBehaviorResponse), 'test_control_behavior result unavailable'
    assert response.isSuccess, 'control_behavior failed'


async def test_stop_behavior():
    # 开始
    block: StartBehavior = StartBehavior(name="dance_0004")
    # response ControlBehaviorResponse
    asyncio.create_task(await block.execute())

    # 5秒后停止
    await asyncio.sleep(5)
    block: StopBehavior = StopBehavior()
    (resultType, response) = await block.execute()
    print(f'test_stop_behavior result: {response}')


# 测试, 设置嘴巴灯颜色为绿色 常亮
async def test_set_mouth_lamp():
    # mode: 嘴巴灯模式，0：普通模式，1：呼吸模式

    # color: 嘴巴灯颜色，1：红色，2：绿色，3：蓝色

    # duration: 持续时间，单位为毫秒，-1表示常亮

    # breath_duration: 闪烁一次时长，单位为毫秒

    """测试设置嘴巴灯

    设置机器人嘴巴灯正常模式、绿色、常亮3s，并等待回复结果

    当mode=NORMAL时，duration参数起作用，表示常亮多久时间

    当mode=BREATH，breath_duration参数起作用，表示多久呼吸一次

    #SetMouthLampResponse.isSuccess : 是否成功

    #SetMouthLampResponse.resultCode : 返回码

    """

    block: SetMouthLamp = SetMouthLamp(color=MouthLampColor.GREEN, mode=MouthLampMode.NORMAL,
                                       duration=3000, breath_duration=1000)
    # response:SetMouthLampResponse
    (resultType, response) = await block.execute()

    print(f'test_set_mouth_lamp result: {response}')

    assert resultType == MiniApiResultType.Success, 'test_set_mouth_lamp timetout'
    assert response is not None and isinstance(response, SetMouthLampResponse), 'test_set_mouth_lamp result unavailable'
    assert response.isSuccess or response.resultCode == 504, 'set_mouth_lamp failed'


# 测试,开关嘴巴灯
async def test_control_mouth_lamp():
    """测试控制嘴巴灯

    让机器人嘴巴灯关闭，并等待结果

    #ControlMouthResponse.isSuccess : 是否成功

    #ControlMouthResponse.resultCode : 返回码

    """
    # is_open: True,False
    # response :ControlMouthResponse
    (resultType, response) = await ControlMouthLamp(is_open=False).execute()

    print(f'test_control_mouth_lamp result: {response}')

    assert resultType == MiniApiResultType.Success, 'test_control_mouth_lamp timetout'
    assert response is not None and isinstance(response,
                                               ControlMouthResponse), 'test_control_mouth_lamp result unavailable'
    assert response.isSuccess or response.resultCode == 504, 'control_mouth_lamp failed'


async def main():
    device: WiFiDevice = await test_get_device_by_name()
    if device:
        await test_connect(device)
        await test_start_run_program()
        await test_play_expression()
        await test_set_mouth_lamp()
        await test_control_mouth_lamp()
        await test_control_behavior()
        await shutdown()


if __name__ == '__main__':
    asyncio.run(main())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_recogniseobject.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_recogniseobject.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\023com.ubtechinc.alpha',
    serialized_pb=b'\n\x1d\x63odemao_recogniseobject.proto\"=\n\x16RecogniseObjectRequest\x12\x12\n\nobjectType\x18\x01 \x01(\x05\x12\x0f\n\x07timeout\x18\x02 \x01(\x05\"Q\n\x17RecogniseObjectResponse\x12\x0f\n\x07objects\x18\x01 \x03(\t\x12\x11\n\tisSuccess\x18\x02 \x01(\x08\x12\x12\n\nresultCode\x18\x03 \x01(\x05\x42\x15\n\x13\x63om.ubtechinc.alphab\x06proto3'
)

_RECOGNISEOBJECTREQUEST = _descriptor.Descriptor(
    name='RecogniseObjectRequest',
    full_name='RecogniseObjectRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='objectType', full_name='RecogniseObjectRequest.objectType', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='timeout', full_name='RecogniseObjectRequest.timeout', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=33,
    serialized_end=94,
)

_RECOGNISEOBJECTRESPONSE = _descriptor.Descriptor(
    name='RecogniseObjectResponse',
    full_name='RecogniseObjectResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='objects', full_name='RecogniseObjectResponse.objects', index=0,
            number=1, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='RecogniseObjectResponse.isSuccess', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='RecogniseObjectResponse.resultCode', index=2,
            number=3, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=96,
    serialized_end=177,
)

DESCRIPTOR.message_types_by_name['RecogniseObjectRequest'] = _RECOGNISEOBJECTREQUEST
DESCRIPTOR.message_types_by_name['RecogniseObjectResponse'] = _RECOGNISEOBJECTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RecogniseObjectRequest = _reflection.GeneratedProtocolMessageType('RecogniseObjectRequest', (_message.Message,), {
    'DESCRIPTOR': _RECOGNISEOBJECTREQUEST,
    '__module__': 'codemao_recogniseobject_pb2'
    # @@protoc_insertion_point(class_scope:RecogniseObjectRequest)
})
_sym_db.RegisterMessage(RecogniseObjectRequest)

RecogniseObjectResponse = _reflection.GeneratedProtocolMessageType('RecogniseObjectResponse', (_message.Message,), {
    'DESCRIPTOR': _RECOGNISEOBJECTRESPONSE,
    '__module__': 'codemao_recogniseobject_pb2'
    # @@protoc_insertion_point(class_scope:RecogniseObjectResponse)
})
_sym_db.RegisterMessage(RecogniseObjectResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



COMMON = (
    (100, "请求参数错误, 请升级系统"),
    (101, "操作未授权，请稍后再试"),
    (102, "悟空忙碌中，请稍后再试"),
    (103, "系统错误，请升级系统"),
    (104, "悟空忙碌中，请稍后再试"),
    (105, "悟空忙碌中，请稍后再试"),
    (106, "悟空忙碌中，请稍后再试"),
    (107, "系统错误，请升级系统"),
    (108, "系统错误，请升级系统"),
    (109, "系统错误，请升级系统"),
    (110, "系统错误，请升级系统"),

    (400, "请求参数错误, 请升级系统"),
    (401, "操作未授权，请稍后再试"),
    (403, "悟空忙碌中，请稍后再试"),
    (404, "系统错误，请升级系统"),
    (408, "悟空忙碌中，请稍后再试"),
    (409, "悟空忙碌中，请稍后再试"),
    (500, "悟空忙碌中，请稍后再试"),
    (501, "系统错误，请升级系统"),
    (504, "系统错误，请升级系统"),
    (1006, "系统错误，请升级系统"),
    (1007, "系统错误，请升级系统"),

    (-61, "该账户已欠费"),
    (-64, "该账户已冻结"),
    (-81, "已开启隐私模式，无法使用该功能"),
    (-92, "已开启隐私模式，无法使用该功能"),
    (-1, "机器人站起失败"),
    (-2, "悟空电量低,请充电后再来点击吧"),
    (-3, "悟空跌倒了，请扶起悟空再试吧"),
    (-4, "悟空正在视频监控中，请稍后再试。"),
    (-5, "悟空正在通话中，请通话结束后再试"),
    (-7, "悟空正在升级中，等我升级完在试吧"),
    (-8, "悟空正在做高难度动作，等他做完再来试试吧"),
    (-9, "悟空还没绑定,请在手机上绑定他吧"),
)
# """
# 通用错误码描述
# """

SPEECH = (
    (1001, "悟空忙碌中，请稍后再试"),
    (1002, "网络错误，请稍后再试"),
    (1003, "TTS内容为空，合成失败"),
    (1004, "播放失败，音频资源已失效"),
    (1005, "音频为空，请选择音效"),
    (1006, "网络错误，请稍后再试"),
    (1007, "网络错误，请稍后再试"),
    (0, ""),
)
# """
# 语音相关错误码描述
# """

CONTENT = (
    (1101, "悟空忙碌中，请稍后再试"),
    (1102, "网络错误，请稍后再试"),
    (1103, "TTS内容为空，合成失败"),
    (1104, "播放失败，音频资源已失效"),
    (0, "音频为空，请选择音效"),
)
# """
# 内容播报相关错误码描述
# """

VISION = (
    (1201, "为检测到人脸，请看着悟空的眼睛，不要晃动"),
    (1202, "你已经录入过人脸信息"),
    (1203, "人脸信息数量已达到上限，请在APP悟空好友中删除人脸后再试"),
    (1204, "人脸信息数量已达到上限，请在APP悟空好友中删除人脸后再试"),
    (1205, "悟空正在录入人脸信息，请稍后再试"),
    (1206, "检测到的人脸过多，请稍后再试"),
    (1207, "人脸录入被打断，请稍后再试"),
    (1208, "悟空电量低，无法添加新的好友"),
    (1209, "网络错误，请稍后再试"),
    (1210, "悟空忙碌中，请稍后再试"),
    (1211, "悟空正在绘本阅读，请稍后再试"),
    (1212, "悟空正处于监控中，请稍后再试"),
    (1213, "悟空正在通话中，请稍后再试"),
    (1214, "网络错误，请稍后再试"),
    (1215, "摄像头启动失败，请重试一下"),
    (1216, "摄像头好像被遮挡了，请移开遮挡物再试试"),
    (1217, "识别超时"),
)
# """
# 侦测类相关错误码描述
# """

MOTION = (
    (1301, "悟空忙碌中，请稍后再试"),
    (1302, "悟空忙碌中，请稍后再试"),
    (1304, "机器人舵机出现故障"),
    (1305, "机器人舵机自我保护"),
    (1306, "缺少文件，请升级系统"),
    (1307, "数据异常，请升级系统"),
    (1308, "数据异常，请升级系统"),
    (1309, "数据异常，请升级系统"),
    (1310, "数据异常，请升级系统"),
    (1311, "动作正在下载中，请稍后再试"),
    (1312, "执行新动作被中断"),
    (1313, "动作stop中断"),
    (1314, "动作stop中断"),
    (1315, "动作stop中断"),
)
# """
# 运动控制相关错误码描述
# """

EXPRESS = (
    (1401, "动作stop中断"),
    (1402, "机器人舵机出现故障"),
    (1403, "机器人舵机自我保护"),
    (1404, "执行新动作被中断"),
    (1405, "缺少文件，请升级系统"),
    (1406, "数据异常，请升级系统"),
    (1407, "数据异常，请升级系统"),
    (1408, "数据异常，请升级系统"),
    (1409, "数据异常，请升级系统"),

    (1410, "动作正在下载中，请稍后再试"),

    (1411, "缺少文件，请升级系统"),
    (1412, "缺少文件，请升级系统"),
    (1413, "数据异常，请升级系统"),
    (1414, "数据异常，请升级系统"),
    (1415, "数据异常，请升级系统"),
    (1416, "悟空忙碌中，请稍后再试"),
    (1417, "数据异常，请升级系统"),
)
# """
# 表情相关错误码描述
# """


def get_common_error_str(error_code: int) -> str:
    """
    把通用错误码映射为错误描述

    Args:
        error_code (int): 错误码，在COMMON中，否则返回"未知错误"

    Returns:
        str : 错误描述

    """
    if error_code == 0:
        return ""

    ret: str = "未知错误"
    for t in COMMON:
        if t[0] == error_code:
            ret = t[1]
            break
    return ret


def get_speech_error_str(error_code: int) -> str:
    """
    把语音相关错误码映射为错误描述

    Args:
        error_code (int): 错误码，在SPEECH中，否则返回None

    Returns:
        str : 错误描述

    """
    ret = None
    for t in SPEECH:
        if t[0] == error_code:
            ret = t[1]
            break
    if ret:
        return ret
    else:
        return get_common_error_str(error_code)


def get_content_error_str(error_code: int) -> str:
    """
    把内容播报相关错误码映射为错误描述

    Args:
        error_code (int): 错误码，在CONTENT中，否则返回None

    Returns:
        str : 错误描述

    """
    ret = None
    for t in CONTENT:
        if t[0] == error_code:
            ret = t[1]
            break
    if ret:
        return ret
    else:
        return get_common_error_str(error_code)


def get_vision_error_str(error_code: int) -> str:
    """
    把侦测类相关错误码映射为错误描述

    Args:
        error_code (int): 错误码，在VISION中，否则返回None

    Returns:
        str : 错误描述

    """
    ret = None
    for t in VISION:
        if t[0] == error_code:
            ret = t[1]
            break
    if ret:
        return ret
    else:
        return get_common_error_str(error_code)


def get_motion_error_str(error_code: int) -> str:
    """
    把运动控制相关错误码映射为错误描述

    Args:
        error_code (int): 错误码，在MOTION中，否则返回None

    Returns:
        str : 错误描述
    """
    ret = None
    for t in MOTION:
        if t[0] == error_code:
            ret = t[1]
            break
    if ret:
        return ret
    else:
        return get_common_error_str(error_code)


def get_express_error_str(error_code: int) -> str:
    """
    把表情相关错误码映射为错误描述

    Args:
        error_code (int): 错误码，在EXPRESS中，否则返回None

    Returns:
        str : 错误描述

    """
    ret = None
    for t in EXPRESS:
        if t[0] == error_code:
            ret = t[1]
            break
    if ret:
        return ret
    else:
        return get_common_error_str(error_code)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_speechrecognise.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='codemao_speechrecognise.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\025com.ubtechinc.codemao',
  serialized_pb=b'\n\x1d\x63odemao_speechrecognise.proto\"<\n\x16SpeechRecogniseRequest\x12\x11\n\ttimeLimit\x18\x01 \x01(\x05\x12\x0f\n\x07\x61srText\x18\x02 \x01(\t\"N\n\x17SpeechRecogniseResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x12\x0c\n\x04text\x18\x03 \x01(\tB\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)




_SPEECHRECOGNISEREQUEST = _descriptor.Descriptor(
  name='SpeechRecogniseRequest',
  full_name='SpeechRecogniseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeLimit', full_name='SpeechRecogniseRequest.timeLimit', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asrText', full_name='SpeechRecogniseRequest.asrText', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=93,
)


_SPEECHRECOGNISERESPONSE = _descriptor.Descriptor(
  name='SpeechRecogniseResponse',
  full_name='SpeechRecogniseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isSuccess', full_name='SpeechRecogniseResponse.isSuccess', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resultCode', full_name='SpeechRecogniseResponse.resultCode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='SpeechRecogniseResponse.text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=173,
)

DESCRIPTOR.message_types_by_name['SpeechRecogniseRequest'] = _SPEECHRECOGNISEREQUEST
DESCRIPTOR.message_types_by_name['SpeechRecogniseResponse'] = _SPEECHRECOGNISERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpeechRecogniseRequest = _reflection.GeneratedProtocolMessageType('SpeechRecogniseRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPEECHRECOGNISEREQUEST,
  '__module__' : 'codemao_speechrecognise_pb2'
  # @@protoc_insertion_point(class_scope:SpeechRecogniseRequest)
  })
_sym_db.RegisterMessage(SpeechRecogniseRequest)

SpeechRecogniseResponse = _reflection.GeneratedProtocolMessageType('SpeechRecogniseResponse', (_message.Message,), {
  'DESCRIPTOR' : _SPEECHRECOGNISERESPONSE,
  '__module__' : 'codemao_speechrecognise_pb2'
  # @@protoc_insertion_point(class_scope:SpeechRecogniseResponse)
  })
_sym_db.RegisterMessage(SpeechRecogniseResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import mini.pkg_tool as Tool

robot_id = "0090"

if __name__ == '__main__':
    # 查询alphamini包信息
    # info = Tool.query_py_pkg(pkg_name="alphamini", robot_id=robot_id)
    # print(f'{info}')
    #
    # # 列出机器人内py包
    # list_info = Tool.list_py_pkg(robot_id=robot_id)
    # print(f'{list_info}')
    #
    # # 安装当前目录下simple_socket-0.0.2-py3-none-any.whl文件
    # Tool.install_py_pkg(package_path="simple_socket-0.0.2-py3-none-any.whl", robot_id=robot_id, debug=True)
    # # 卸载simple_socket
    # Tool.uninstall_py_pkg(pkg_name="simple-socket", robot_id=robot_id, debug=True)

    # 将当前目录下的tts_demo工程打包成py wheel， 返回值为打包生成后的wheel路径
    pkg_path = Tool.setup_py_pkg("tts_demo")
    print(f'{pkg_path}')

    # 卸载tts_demo
    Tool.uninstall_py_pkg(pkg_name="tts_demo", robot_id=robot_id)

    # 重新安装打包后的tts_demo
    Tool.install_py_pkg(package_path=pkg_path, robot_id=robot_id, debug=False)

    # 触发tts_demo脱机执行
    Tool.run_py_pkg("tts_demo", robot_id=robot_id)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_setmouthlamp.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='codemao_setmouthlamp.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\025com.ubtechinc.codemao',
  serialized_pb=b'\n\x1a\x63odemao_setmouthlamp.proto\"\x96\x01\n\x13SetMouthLampRequest\x12\r\n\x05model\x18\x01 \x01(\x05\x12\r\n\x05\x63olor\x18\x02 \x01(\x05\x12\x10\n\x08\x64uration\x18\x03 \x01(\x05\x12\x16\n\x0e\x62reathDuration\x18\x04 \x01(\x05\x12\x10\n\x08redValue\x18\x05 \x01(\x05\x12\x12\n\ngreenValue\x18\x06 \x01(\x05\x12\x11\n\tblueValue\x18\x07 \x01(\x05\"=\n\x14SetMouthLampResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)




_SETMOUTHLAMPREQUEST = _descriptor.Descriptor(
  name='SetMouthLampRequest',
  full_name='SetMouthLampRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model', full_name='SetMouthLampRequest.model', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color', full_name='SetMouthLampRequest.color', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='SetMouthLampRequest.duration', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='breathDuration', full_name='SetMouthLampRequest.breathDuration', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redValue', full_name='SetMouthLampRequest.redValue', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='greenValue', full_name='SetMouthLampRequest.greenValue', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blueValue', full_name='SetMouthLampRequest.blueValue', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=181,
)


_SETMOUTHLAMPRESPONSE = _descriptor.Descriptor(
  name='SetMouthLampResponse',
  full_name='SetMouthLampResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isSuccess', full_name='SetMouthLampResponse.isSuccess', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resultCode', full_name='SetMouthLampResponse.resultCode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=244,
)

DESCRIPTOR.message_types_by_name['SetMouthLampRequest'] = _SETMOUTHLAMPREQUEST
DESCRIPTOR.message_types_by_name['SetMouthLampResponse'] = _SETMOUTHLAMPRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SetMouthLampRequest = _reflection.GeneratedProtocolMessageType('SetMouthLampRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETMOUTHLAMPREQUEST,
  '__module__' : 'codemao_setmouthlamp_pb2'
  # @@protoc_insertion_point(class_scope:SetMouthLampRequest)
  })
_sym_db.RegisterMessage(SetMouthLampRequest)

SetMouthLampResponse = _reflection.GeneratedProtocolMessageType('SetMouthLampResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETMOUTHLAMPRESPONSE,
  '__module__' : 'codemao_setmouthlamp_pb2'
  # @@protoc_insertion_point(class_scope:SetMouthLampResponse)
  })
_sym_db.RegisterMessage(SetMouthLampResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import asyncio
import logging
from asyncio.futures import Future

import enum
from google.protobuf import message as _message
from typing import Any, Set, Optional

from mini import MoveRobotDirection, MiniApiResultType, MouthLampMode, \
    MouthLampColor, ServicePlatform, LanType
from mini.pb2.codemao_faceanalyze_pb2 import FaceAnalyzeResponse
from mini.pb2.codemao_facedetect_pb2 import FaceDetectResponse
from mini.pb2.codemao_facerecognise_pb2 import FaceRecogniseResponse
from mini.pb2.codemao_getaudiolist_pb2 import GetAudioListResponse
from mini.pb2.codemao_getinfrareddistance_pb2 import GetInfraredDistanceResponse
from mini.pb2.codemao_getregisterfaces_pb2 import GetRegisterFacesResponse
from mini.pb2.codemao_recogniseobject_pb2 import RecogniseObjectResponse
from mini.pb2.codemao_speechrecognise_pb2 import SpeechRecogniseResponse
from mini.pb2.codemao_takepicture_pb2 import TakePictureResponse
from .channels.websocket_client import AbstractMsgHandler as _AbstractMsgHandler
from .channels.websocket_client import ubt_websocket as _websocket
from .dns.dns_browser import WiFiDeviceListener, WiFiDevice
from .dns.dns_browser import browser as _browser

_log = logging.getLogger(__name__)
_log.addHandler(logging.StreamHandler())
if _log.level == logging.NOTSET:
    _log.setLevel(logging.INFO)

browser = _browser()
websocket = _websocket()


def set_log_level(level: int, save_file: str = None):
    """设置sdk日志级别

    Args:
        level: logging.DEBUG, logging.INFO, logging.WARNING, logging.ERROR
        save_file: 需要保存到文件的, 填写日志文件路径

    """
    _log.setLevel(level)

    from .dns.dns_browser import log as log1
    log1.setLevel(level)

    from .channels.websocket_client import log as log2
    log2.setLevel(level)

    from .dns.zeroconf import log as log3
    log3.setLevel(level)
    log3.addHandler(logging.StreamHandler())

    if save_file is not None:
        file_handler = logging.FileHandler(save_file)
        _log.addHandler(file_handler)
        log1.addHandler(file_handler)
        log2.addHandler(file_handler)


@enum.unique
class RobotType(enum.Enum):
    """
    机器人产品类型
    """
    DEDU = 1
    """
    悟空国内教育版
    """
    MINI = 2
    """
    悟空标准版
    """
    EDU = 3
    """悟空海外教育版
    """
    KOR = 4
    """悟空韩国版
    """


def set_robot_type(robot: RobotType):
    """设置要链接的机器人产品类型

    Args:
        robot: 取值为: RobotType.DEDU , RobotType.MINI, RobotType.EDU, RobotType.KOR

    """
    if robot == RobotType.MINI:
        from .dns import dns_browser
        dns_browser.service_type = "_Mini_mini_channel_server._tcp.local."
    elif robot == RobotType.DEDU:
        from .dns import dns_browser
        dns_browser.service_type = "_Dedu_mini_channel_server._tcp.local."
    elif robot == RobotType.EDU:
        from .dns import dns_browser
        dns_browser.service_type = "_Edu_mini_channel_server._tcp.local."
    elif robot == RobotType.KOR:
        from .dns import dns_browser
        dns_browser.service_type = "_Kor_mini_channel_server._tcp.local."
    else:
        print(f"不支持的机器人产品类型")


class _GetWiFiDeviceListListener(WiFiDeviceListener):
    """批量获取机器人设备监听类

    Args:
        devices: Set[WiFiDevice] or None
    """
    devices: Set[WiFiDevice]

    def __init__(self, devices):
        self.devices: Set[WiFiDevice] = devices or set()

    def on_device_updated(self, device: WiFiDevice) -> None:
        """
        机器人设备更新了
        Args:
            device: WiFiDevice
        """
        self.devices.update([device])

    def on_device_removed(self, device: WiFiDevice) -> None:
        """
        机器人设备从局域网中移除了
        Args:
            device: WFiDevice
        """
        self.devices.remove(device)

    def on_device_found(self, device: WiFiDevice) -> None:
        """
        扫描到一个机器人设备
        Args:
            device: WFiDevice
        """
        self.devices.add(device)


async def _get_user_input(devices: tuple) -> int:
    try:
        i: int = 0
        for device in devices:
            print('{0}.{1}'.format(i, device))
            i += 1
        num_text = input(f'请输入选择连接的机器人序号:')
    except Exception as e:
        raise e
    else:
        return int(num_text)


def _start_scan(loop: asyncio.AbstractEventLoop, name: str) -> Future:
    """
    开启一个扫描机器人设备的Future
    Args:
        loop: 当前事件loop
        name: 指定设备名称

    Returns:
        asyncio.Future
    """
    fut = loop.create_future()

    class _InnerLister(WiFiDeviceListener):

        @staticmethod
        def set_result(future: Future, device: WiFiDevice):
            if future.cancelled() or future.done():
                return
            _log.info(f"found device : {device}")
            future.set_result(device)

        def on_device_found(self, device: WiFiDevice) -> None:
            if device.name.endswith(name):
                if fut.cancelled() or fut.done():
                    return
                loop.run_in_executor(None, browser.stop_scan)
                loop.call_soon(_InnerLister.set_result, fut, device)

        def on_device_updated(self, device: WiFiDevice) -> None:
            if device.name.endswith(name):
                if fut.cancelled() or fut.done():
                    return
                loop.run_in_executor(None, browser.stop_scan)
                loop.call_soon(_InnerLister.set_result, fut, device)

        def on_device_removed(self, device: WiFiDevice) -> None:
            if device.name.endswith(name):
                if fut.cancelled() or fut.done():
                    return
                loop.call_soon(_InnerLister.set_result, fut, device)

    _log.info("start scanning...")
    browser.add_listener(_InnerLister())
    browser.start_scan(0)

    return fut


async def _get_device_by_name(name: str, timeout: int) -> Optional[WiFiDevice]:
    """
    获取当前局域网内，指定名字的机器人设备信息
    Args:
        name: 设备序列号
        timeout: 扫描超时时间

    Returns:
        Optional[WiFiDevice]
    """

    async def start_scan_async():
        return await _start_scan(asyncio.get_running_loop(), name)

    try:
        device: WiFiDevice = await asyncio.wait_for(start_scan_async(), timeout)
        return device
    except asyncio.TimeoutError:
        _log.warning(f'scan device timeout')
        return None
    finally:
        browser.stop_scan()
        _log.info("stop scan finished.")


async def _get_device_list(timeout: int) -> tuple:
    """
    获取当前局域网内所有机器人设备信息
    Args:
        timeout: 超时时间

    Returns:
        Optional[WiFiDevice]
    """
    devices: Set[WiFiDevice] = set()
    browser.add_listener(_GetWiFiDeviceListListener(devices))
    browser.start_scan(0)
    await asyncio.sleep(timeout)
    browser.remove_all_listener()
    browser.stop_scan()
    return tuple(devices)


async def _connect(device: WiFiDevice) -> bool:
    """
    连接机器人设备

    Args:
        device (WiFiDevice): 指定机器人设备对象

    Returns:
        bool: 是否连接设备成功

    """
    return await websocket.connect(device.address)


def _register_msg_handler(cmd: int, handler: _AbstractMsgHandler):
    """
    注册命令监听器

    Args:
        cmd: 支持的命令请查看: mini.apis.cmdid
        handler: 命令处理器

    """
    websocket.register_msg_handler(cmd, handler)


def _unregister_msg_handler(cmd: int, handler: _AbstractMsgHandler):
    """
    反注册命令监听器

    Args:
        cmd: 支持的命令请查看: mini.apis.cmdid
        handler: 命令处理器
    """
    websocket.unregister_msg_handler(cmd, handler)


async def _send_msg(cmd: int, message: _message.Message, timeout: int) -> Any:
    """
    发送一个消息给机器人

    Args:
        cmd:支持的命令请查看: mini.apis.cmdid
        message:  消息类在: mini.pb2 包内
        timeout: 超时时间
    """
    return await websocket.send_msg(cmd, message, timeout)


async def _release():
    """
    断开链接，释放资源
    """
    await websocket.shutdown()


# -----------------------------------------------------------------#
async def get_device_by_name(name: str, timeout: int) -> Optional[WiFiDevice]:
    """
    获取当前局域网内，指定名字的机器人设备信息

    Args:
        name: 设备序列号
        timeout: 扫描超时时间

    Returns:
        Optional[WiFiDevice]
    """
    return await _get_device_by_name(name, timeout)


async def get_device_list(timeout: int) -> tuple:
    """获取当前局域网内所有机器人设备信息

    Args:
        timeout: 超时时间

    Returns:
        Optional[WiFiDevice]
    """
    return await _get_device_list(timeout)


async def connect(device: WiFiDevice) -> bool:
    """连接机器人设备

    Args:
        device (WiFiDevice): 指定机器人设备对象

    Returns:
        bool: 是否连接设备成功
    """
    return await _connect(device)


async def release():
    """
    断开链接，释放资源
    """
    await _release()


async def enter_program() -> bool:
    """进入编程模式api

        机器人进入编程模式

    Returns:
        bool
    """

    from mini.apis.api_setup import StartRunProgram
    (resultType, response) = await StartRunProgram().execute()
    await asyncio.sleep(6)
    return resultType == MiniApiResultType.Success and response.isSuccess


async def quit_program() -> bool:
    """退出编程模式api

            机器人退出编程模式

        Returns:
            bool
        """

    from mini.apis.api_setup import StopRunProgram
    return await StopRunProgram(is_serial=False).execute()


async def play_action(action_name: str = None) -> bool:
    """执行内置动作api

        机器人执行一个指定名称的内置动作

        动作名称可用get_action_list获取

    Args:
        action_name (str): 动作名称

    Returns:
        bool
    """
    from mini.apis.api_action import PlayAction
    block: PlayAction = PlayAction(True, action_name)
    (resultType, response) = await block.execute()
    _log.info(f'play_action result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def stop_action() -> bool:
    """停止动作

        如果动作是一个不可打断的动作, stop_action返回False

        Returns:
            bool
    """
    from mini.apis.api_action import StopAllAction
    block: StopAllAction = StopAllAction()
    (resultType, response) = await block.execute()
    _log.info(f'stop_action result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def play_custom_action(action_name: str = None) -> bool:
    """执行自定义动作api

    让机器人执行一个指定名称的自定义动作, 并等待结果

    动作名称可用get_custom_action_list获取

    Args:
        action_name (str): 自定义动作名称

    Returns:
        bool
    """
    from mini.apis.api_action import PlayCustomAction
    block: PlayCustomAction = PlayCustomAction(True, action_name)
    (resultType, response) = await block.execute()
    _log.info(f'play_custom_action result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def stop_custom_action() -> bool:
    """停止自定义动作

        如果动作是一个不可打断的动作, stop_action返回False

    Returns:
        bool
    """

    from mini.apis.api_action import StopCustomAction
    block: StopCustomAction = StopCustomAction()
    (resultType, response) = await block.execute()
    _log.info(f'stop_custom_action result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def move(direction: MoveRobotDirection = MoveRobotDirection.FORWARD,
               step: int = 1) -> bool:
    """控制机器人移动

        控制机器人往左(LEFTWARD)移动10步，并等待执行结果

    Args:
        direction (MoveRobotDirection): 方向
        step (int): 步数

    Returns:
        bool
    """

    from mini.apis.api_action import MoveRobot
    block: MoveRobot = MoveRobot(True, direction, step)
    (resultType, response) = await block.execute()
    _log.info(f'move result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def get_action_list() -> list:
    """获取取动作列表

        获取机器人系统内置的动作列表，等待回复结果

    Returns:
        [] : 动作列表
    """
    from mini.apis.api_action import GetActionList
    from mini import RobotActionType
    block: GetActionList = GetActionList(True, RobotActionType.INNER)
    (resultType, response) = await block.execute()
    if resultType == MiniApiResultType.Success and response.isSuccess:
        return response.actionList
    else:
        return []


async def get_custom_action_list() -> list:
    """获取自定义动作列表

        获取机器人/sdcard/customize/actions下的动作列表，等待回复结果

    Returns:
        [] : 自定义动作列表
    """

    from mini.apis.api_action import GetActionList
    from mini import RobotActionType
    block: GetActionList = GetActionList(True, RobotActionType.INNER)
    (resultType, response) = await block.execute()
    if resultType == MiniApiResultType.Success and response.isSuccess:
        return response.actionList
    else:
        return []


async def wiki(query: str) -> bool:
    """查询百科demo

        查询百科，例如：查询内容"优必选"，并等待结果，机器人播报查询结果

    Args:
        query (str): 查询关键字

    Returns:
        bool
    """

    from mini.apis.api_content import QueryWiKi
    block: QueryWiKi = QueryWiKi(True, query)
    (resultType, response) = await block.execute()
    _log.info(f'wiki result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def translate(query: str,
                    from_lan: LanType = None, to_lan: LanType = None,
                    platform: ServicePlatform = ServicePlatform.BAIDU) -> bool:
    """翻译

        例如:使用百度翻译，把"张学友"，从中文翻译成英文，并等待结果，机器人播报翻译结果:

        translate(query="张学友",from_lan=CN,to_lan=EN,platform=BAIDU )

    Args:
        query (str): 关键字
        from_lan (LanType): 源语言
        to_lan (LanType): 目标语言
        platform (ServicePlatform): BAIDU, GOOGLE, TENCENT

    Returns:
        bool
    """

    from mini.apis.api_content import StartTranslate
    block: StartTranslate = StartTranslate(True, query, from_lan=from_lan, to_lan=to_lan, platform=platform)
    (resultType, response) = await block.execute()
    _log.info(f'translate result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def play_expression(express_name: str) -> bool:
    """播放表情

        让机器人播放一个express_name的内置表情，并等待回复结果

    Args:
        express_name (str): 表情文件名,如:"codemao1"
    Returns:
        bool
    """

    from mini.apis.api_expression import PlayExpression
    block: PlayExpression = PlayExpression(True, express_name)
    (resultType, response) = await block.execute()
    _log.info(f'play expression result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def play_behavior(behavior_name: str) -> bool:
    """播放舞蹈

        让机器人开始跳一个名为behavior_name的舞蹈，并等待回复结果

    Args:
        behavior_name (str): 例如"dance_0004"

    Returns:
        bool
    """

    from mini.apis.api_behavior import StartBehavior
    block: StartBehavior = StartBehavior(True, behavior_name)
    (resultType, response) = await block.execute()
    _log.info(f'play behavior result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def stop_behavior() -> bool:
    """停止正在播放的舞蹈

    Returns:
        bool
    """
    from mini.apis.api_behavior import StopBehavior
    block: StopBehavior = StopBehavior(True)
    (resultType, response) = await block.execute()
    _log.info(f'stop behavior result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def set_MouthLamp_NormalMode(color: MouthLampColor = MouthLampColor.RED, duration: int = 1000) -> bool:
    """
    设置嘴巴灯常亮模式，并等待结果

    Args:
        color (MouthLampColor): 嘴巴灯颜色，默认RED
        duration (int): 单位ms，持续时间

    Returns:
        bool

    """
    return await _set_mouthlamp_mode(mode=MouthLampMode.NORMAL, color=color, duration=duration)


async def set_MouthLamp_BreathMode(breath_duration: int = 1000,
                                   color: MouthLampColor = MouthLampColor.RED, duration: int = 1000) -> bool:
    """
    设置嘴巴灯呼吸模式，并等待结果

    Args:
        breath_duration (int): 单位ms，呼吸一次的时长
        color (MouthLampColor): 嘴巴灯颜色，默认RED
        duration (int): 单位ms，持续时间


    Returns:
        bool
    """
    return await _set_mouthlamp_mode(mode=MouthLampMode.BREATH, breath_duration=breath_duration, color=color,
                                     duration=duration)


async def _set_mouthlamp_mode(mode: MouthLampMode = MouthLampMode.NORMAL, color: MouthLampColor = MouthLampColor.RED,
                              duration: int = 1000, breath_duration: int = 1000) -> bool:
    """设置嘴巴灯模式

        设置机器人嘴巴灯正常模式、绿色、常亮3s，并等待回复结果

        当mode=NORMAL时，duration参数起作用，表示常亮多久时间

        当mode=BREATH，breath_duration参数表示多久呼吸一次

        设置生效后，机器人会立即返回设置结果(与设置的duration参数无关)

    Args:
        mode: 嘴巴灯模式，0：普通模式，1：呼吸模式
        color: 嘴巴灯颜色，1：红色，2：绿色，3：蓝色
        duration: 持续时间，单位为毫秒，-1表示常亮
        breath_duration: 闪烁一次时长，单位为毫秒

    Returns:
        bool
    """

    from mini.apis.api_expression import SetMouthLamp
    block: SetMouthLamp = SetMouthLamp(True, mode, color, duration, breath_duration)
    (resultType, response) = await block.execute()
    _log.info(f'set MouthLamp mode result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def switch_MouthLamp(is_open: bool = True) -> bool:
    """开关嘴巴灯

        开关机器人嘴巴灯，并等待结果

    Args:
        is_open: bool

    Returns:
        bool
    """

    from mini.apis.api_expression import ControlMouthLamp
    block: ControlMouthLamp = ControlMouthLamp(True, is_open)
    (resultType, response) = await block.execute()
    _log.info(f'switch MouthLamp result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def play_tts(text: str) -> bool:
    """播放tts

        使机器人开始播放一段tts，并等待结果

    Args:
        text: str, 例如:"你好， 我是悟空， 啦啦啦"，

    Returns:
        bool
    """

    from mini.apis.api_sound import StartPlayTTS
    block: StartPlayTTS = StartPlayTTS(True, text)
    (resultType, response) = await block.execute()
    _log.info(f'play tts result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def stop_tts() -> bool:
    """停止语音合成播报, 并等待结果

    Returns:
        bool
    """

    from mini.apis.api_sound import StopPlayTTS
    block: StopPlayTTS = StopPlayTTS(True)
    (resultType, response) = await block.execute()
    _log.info(f'stop tts result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def play_online_audio(url: str) -> bool:
    """播放在线音效

        使机器人播放一段在线音效，

        并等待结果

    Args:
        url: str, 例如:http://yun.lnpan.com/music/download/ring/000/075/5653bae83917a892589b372782175dd8.amr
             支持格式有mp3,amr,wav 等
    Returns:
        bool
    """

    from mini import AudioStorageType
    from mini.apis.api_sound import PlayAudio
    block: PlayAudio = PlayAudio(True,
                                 url,
                                 AudioStorageType.NET_PUBLIC)
    (resultType, response) = await block.execute()
    _log.info(f'play online audio result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def play_local_audio(local_file: str) -> bool:
    """播放本地音效

        使机器人播放一段本地内置音效，音效名称为"read_016"，并等待结果

    Args:
        local_file:

    Returns:
        bool
    """

    from mini.apis.api_sound import PlayAudio
    from mini import AudioStorageType
    block: PlayAudio = PlayAudio(True,
                                 local_file,
                                 AudioStorageType.PRESET_LOCAL)
    (resultType, response) = await block.execute()
    _log.info(f'play local audio result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def stop_audio() -> bool:
    """停止所有正在播放的音频

        停止所有所有音效，并等待结果

    Returns:
        bool
    """

    from mini.apis.api_sound import StopAllAudio
    block: StopAllAudio = StopAllAudio(True)
    (resultType, response) = await block.execute()
    _log.info(f'stop audio result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def get_system_audio_list() -> GetAudioListResponse:
    """获取音效列表

        获取机器人内置的音效列表，并等待结果

        #GetAudioListResponse.audio ([Audio]) : 音效列表

            #Audio.name : 音效名

            #Audio.suffix : 音效后缀

        #GetAudioListResponse.isSuccess : 是否成功

        #GetAudioListResponse.resultCode : 返回码

    Returns:
        GetAudioListResponse
    """

    from mini.apis.api_sound import FetchAudioList
    from mini import AudioSearchType
    block: FetchAudioList = FetchAudioList(True, search_type=AudioSearchType.INNER)
    (resultType, response) = await block.execute()
    _log.info(f'stop audio result:{response}')
    return response


async def get_custom_audio_list() -> GetAudioListResponse:
    """获取音效列表

        获取机器人开发者放置在/sdcard/customize/music/下的音效列表，并等待结果

        #GetAudioListResponse.audio ([Audio]) : 音效列表

            #Audio.name : 音效名

            #Audio.suffix : 音效后缀

        #GetAudioListResponse.isSuccess : 是否成功

        #GetAudioListResponse.resultCode : 返回码

    Returns:
        GetAudioListResponse
    """

    from mini.apis.api_sound import FetchAudioList
    from mini import AudioSearchType
    block: FetchAudioList = FetchAudioList(True, search_type=AudioSearchType.CUSTOM)
    (resultType, response) = await block.execute()
    _log.info(f'stop audio result:{response}')
    return response


async def change_volume(volume: float = 0.5) -> bool:
    """调整机器人音量demo

        设置机器人音量为0~1，等待回复结果

    Args:
        volume: float 默认0.5

    Returns:
        bool
    """

    from mini.apis.api_sound import ChangeRobotVolume
    block: ChangeRobotVolume = ChangeRobotVolume(True, volume)
    (resultType, response) = await block.execute()
    _log.info(f'change volume result:{response}')
    return resultType == MiniApiResultType.Success and response.isSuccess


async def face_detect() -> FaceDetectResponse:
    """人脸个数侦测

        做一次人脸个数侦测，并等待回复结果

        #FaceDetectResponse.count : 人脸个数

        #FaceDetectResponse.isSuccess : 是否成功

        #FaceDetectResponse.resultCode : 返回码

    Returns:
        FaceDetectResponse
    """

    from mini.apis.api_sence import FaceDetect
    block: FaceDetect = FaceDetect(True, 10)
    (resultType, response) = await block.execute()
    _log.info(f'face detect result:{response}')
    return response


async def face_analysis() -> FaceAnalyzeResponse:
    """人脸分析（性别）

        做一次人脸信息(性别、年龄)侦测，并等待回复结果

        当多人存在摄像头前时，返回占画面比例最大的那个人脸信息

        返回值：示例 {"age": 24, "gender": 99, "height": 238, "width": 238}

                age: 年龄

                gender：[1, 100], 小于50为女性，大于50为男性

                height：人脸在摄像头画面中的高度

                width：人脸在摄像头画面中的宽度

        #FaceAnalyzeResponse.faceInfos : 人脸信息数组[FaceInfoResponse]

        #FaceInfoResponse.gender (int) :[1,100],小于50为女性，大于50为男性

        #FaceInfoResponse.age : 年龄

        #FaceInfoResponse.width : 人脸在摄像头画面中的宽度

        #FaceInfoResponse.height : 人脸在摄像头画面中的高度

        #FaceAnalyzeResponse.isSuccess : 是否成功

        #FaceAnalyzeResponse.resultCode : 返回码

    Returns:
        FaceAnalyzeResponse
    """

    from mini.apis.api_sence import FaceAnalysis
    block: FaceAnalysis = FaceAnalysis(True, 10)
    (resultType, response) = await block.execute()
    _log.info(f'face analysis result:{response}')
    return response


async def face_recognise() -> FaceRecogniseResponse:
    """人脸识别

        做一次人脸识别检测，并等待结果

        #FaceRecogniseResponse.faceInfos : [FaceInfoResponse] 人脸信息数组

            #FaceInfoResponse.id : 人脸id

            #FaceInfoResponse.name : 姓名，如果是陌生人，则默认name为"stranger"

            #FaceInfoResponse.gender : 性别

            #FaceInfoResponse.age : 年龄

        #FaceRecogniseResponse.isSuccess : 是否成功

        #FaceRecogniseResponse.resultCode : 返回码

    Returns:
        RecogniseObjectResponse
    """

    from mini.apis.api_sence import FaceRecognise
    (resultType, response) = await FaceRecognise(True, 10).execute()
    _log.info(f'face recognise result:{response}')
    return response


async def flower_recognise() -> RecogniseObjectResponse:
    """花草识别

        让机器人做一次花草识别, (需手动把花或花的照片放到机器人面前)，并等待结果

        #RecogniseObjectResponse.objects : 识别结果数组[str]

        #RecogniseObjectResponse.isSuccess : 是否成功

        #RecogniseObjectResponse.resultCode : 返回码

    Returns:
        RecogniseObjectResponse
    """

    from mini.apis.api_sence import ObjectRecognise
    from mini import ObjectRecogniseType
    block: ObjectRecognise = ObjectRecognise(True, ObjectRecogniseType.FLOWER, 10)
    (resultType, response) = await block.execute()
    _log.info(f'flower_recognise result:{response}')
    return response


async def fruit_recognise() -> RecogniseObjectResponse:
    """水果识别

        让机器人做一次水果识别, (需手动把水果或水果的照片放到机器人面前)，并等待结果

        #RecogniseObjectResponse.objects : 识别结果数组[str]

        #RecogniseObjectResponse.isSuccess : 是否成功

        #RecogniseObjectResponse.resultCode : 返回码

    Returns:
        RecogniseObjectResponse
    """

    from mini.apis.api_sence import ObjectRecognise
    from mini import ObjectRecogniseType
    block: ObjectRecognise = ObjectRecognise(True, ObjectRecogniseType.FRUIT, 10)
    (resultType, response) = await block.execute()
    _log.info(f'fruit_recognize result:{response}')
    return response


async def gesture_recognise() -> RecogniseObjectResponse:
    """手势识别

        让机器人做一次用户手势识别, (需在机器人面前作出手势)，并等待结果

        #RecogniseObjectResponse.objects : 识别结果数组[str]

        #RecogniseObjectResponse.isSuccess : 是否成功

        #RecogniseObjectResponse.resultCode : 返回码

    Returns:
        RecogniseObjectResponse
    """

    from mini.apis.api_sence import ObjectRecognise
    from mini import ObjectRecogniseType
    block: ObjectRecognise = ObjectRecognise(True, ObjectRecogniseType.GESTURE, 10)
    (resultType, response) = await block.execute()
    _log.info(f'gesture_recognize result:{response}')
    return response


async def take_picture_immediately() -> TakePictureResponse:
    """拍照

        让机器人立即拍照，并等待结果

        #TakePictureResponse.isSuccess : 是否成功

        #TakePictureResponse.code : 返回码

        #TakePictureResponse.picPath : 照片在机器人里的存储路径

    Returns:
        TakePictureResponse
    """

    from mini.apis.api_sence import TakePicture
    from mini import TakePictureType
    (resultType, response) = await TakePicture(take_picture_type=TakePictureType.IMMEDIATELY).execute()
    _log.info(f'take picture immediately result:{response}')
    return response


async def take_picture() -> TakePictureResponse:
    """拍照

        让机器人查找人脸后再拍照，并等待结果

        #TakePictureResponse.isSuccess : 是否成功

        #TakePictureResponse.code : 返回码

        #TakePictureResponse.picPath : 照片在机器人里的存储路径

    Returns:
        TakePictureResponse
    """

    from mini.apis.api_sence import TakePicture
    from mini import TakePictureType
    (resultType, response) = await TakePicture(take_picture_type=TakePictureType.FINDFACE).execute()
    _log.info(f'take picture result:{response}')
    return response


async def get_register_faces() -> GetRegisterFacesResponse:
    """获取已注册的人脸信息

        获取在机器人中已注册的所有人脸信息，并等待结果

        #GetRegisterFacesResponse.faceInfos : [FaceInfoResponse] 人脸信息数组

            #FaceInfoResponse.id : 人脸id

            #FaceInfoResponse.name : 姓名

            #FaceInfoResponse.gender : 性别

            #FaceInfoResponse.age : 年龄

        #GetRegisterFacesResponse.isSuccess : 是否成功

        #GetRegisterFacesResponse.resultCode : 返回码

    Returns:
        GetRegisterFacesResponse

    """

    from mini.apis.api_sence import GetRegisterFaces
    (resultType, response) = await GetRegisterFaces().execute()
    _log.info(f'get register faces result:{response}')
    return response


async def get_infrared_distance() -> GetInfraredDistanceResponse:
    """红外距离检测

        获取当前机器人检测到的红外距离，并等待结果

        #GetInfraredDistanceResponse.distance : 红外距离

    Returns:
        GetInfraredDistanceResponse
    """

    from mini.apis.api_sence import GetInfraredDistance
    (resultType, response) = await GetInfraredDistance().execute()
    _log.info(f'get infrared distance result:{response}')
    return response


async def speech_recognise(timeout: int) -> SpeechRecogniseResponse:
    """语音识别api

        机器人在指定时间内，执行语音识别
    Args:
        timeout (int): 超时时间

    Returns:
        bool
    """
    from mini.apis.api_sence import StartSpeechRecognise
    block: StartSpeechRecognise = StartSpeechRecognise(True, timeout)
    (resultType, response) = await block.execute()
    _log.info(f'speech_recognise result:{response}')
    return response



import asyncio

from mini import mini_sdk as MiniSdk
from mini.apis.api_action import GetActionList, GetActionListResponse, RobotActionType
from mini.apis.api_action import MoveRobot, MoveRobotDirection, MoveRobotResponse
from mini.apis.api_action import PlayAction, PlayActionResponse
from mini.apis.base_api import MiniApiResultType
from mini.dns.dns_browser import WiFiDevice
from test.test_connect import test_get_device_by_name


# 测试, 执行一个动作文件
async def test_play_action():
    """执行一个动作demo

    控制机器人执行一个指定名称的本地(内置/自定义)动作，并等待执行结果回复

    动作名称可用GetActionList获取

    #PlayActionResponse.isSuccess : 是否成功

    #PlayActionResponse.resultCode : 返回码

    """
    # action_name: 动作文件名, 可以通过GetActionList获取机器人支持的动作
    block: PlayAction = PlayAction(action_name='018')
    # response: PlayActionResponse
    (resultType, response) = await block.execute()

    print(f'test_play_action result:{response}')

    assert resultType == MiniApiResultType.Success, 'test_play_action timetout'
    assert response is not None and isinstance(response, PlayActionResponse), 'test_play_action result unavailable'
    assert response.isSuccess, 'play_action failed'


# 测试, 控制机器人,向前/后/左/右 移动
async def test_move_robot():
    """控制机器人移动demo

    控制机器人往左(LEFTWARD)移动10步，并等待执行结果

    #MoveRobotResponse.isSuccess : 是否成功　

    #MoveRobotResponse.code : 返回码

    """
    # step: 移动几步
    # direction: 方向,枚举类型
    block: MoveRobot = MoveRobot(step=10, direction=MoveRobotDirection.LEFTWARD)
    # response : MoveRobotResponse
    (resultType, response) = await block.execute()

    print(f'test_move_robot result:{response}')

    assert resultType == MiniApiResultType.Success, 'test_move_robot timetout'
    assert response is not None and isinstance(response, MoveRobotResponse), 'test_move_robot result unavailable'
    assert response.isSuccess, 'move_robot failed'


# 测试, 获取支持的动作文件列表
async def test_get_action_list():
    """获取动作列表demo

    获取机器人内置的动作列表，等待回复结果

    """
    # action_type: INNER 是指机器人内置的不可修改的动作文件, CUSTOM 是放置在sdcard/customize/action目录下可被开发者修改的动作
    block: GetActionList = GetActionList(action_type=RobotActionType.INNER)
    # response:GetActionListResponse
    (resultType, response) = await block.execute()

    print(f'test_get_action_list result:{response}')

    assert resultType == MiniApiResultType.Success, 'test_get_action_list timetout'
    assert response is not None and isinstance(response,
                                               GetActionListResponse), 'test_get_action_list result unavailable'
    assert response.isSuccess, 'get_action_list failed'


async def main():
    device: WiFiDevice = await test_get_device_by_name()
    if device:
        await MiniSdk.connect(device)
        await MiniSdk.enter_program()
        await test_play_action()
        await test_move_robot()
        await test_get_action_list()
        await MiniSdk.quit_program()
        await MiniSdk.release()


if __name__ == '__main__':
    asyncio.run(main())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PyPi_AdbSwitch.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='PyPi_AdbSwitch.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\023com.ubtechinc.alpha',
  serialized_pb=b'\n\x14PyPi_AdbSwitch.proto\" \n\x10\x41\x64\x62SwitchRequest\x12\x0c\n\x04open\x18\x01 \x01(\x08\":\n\x11\x41\x64\x62SwitchResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x15\n\x13\x63om.ubtechinc.alphab\x06proto3'
)




_ADBSWITCHREQUEST = _descriptor.Descriptor(
  name='AdbSwitchRequest',
  full_name='AdbSwitchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='open', full_name='AdbSwitchRequest.open', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=56,
)


_ADBSWITCHRESPONSE = _descriptor.Descriptor(
  name='AdbSwitchResponse',
  full_name='AdbSwitchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isSuccess', full_name='AdbSwitchResponse.isSuccess', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resultCode', full_name='AdbSwitchResponse.resultCode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=116,
)

DESCRIPTOR.message_types_by_name['AdbSwitchRequest'] = _ADBSWITCHREQUEST
DESCRIPTOR.message_types_by_name['AdbSwitchResponse'] = _ADBSWITCHRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdbSwitchRequest = _reflection.GeneratedProtocolMessageType('AdbSwitchRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADBSWITCHREQUEST,
  '__module__' : 'PyPi_AdbSwitch_pb2'
  # @@protoc_insertion_point(class_scope:AdbSwitchRequest)
  })
_sym_db.RegisterMessage(AdbSwitchRequest)

AdbSwitchResponse = _reflection.GeneratedProtocolMessageType('AdbSwitchResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADBSWITCHRESPONSE,
  '__module__' : 'PyPi_AdbSwitch_pb2'
  # @@protoc_insertion_point(class_scope:AdbSwitchResponse)
  })
_sym_db.RegisterMessage(AdbSwitchResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import click


@click.command()
@click.argument('pkg_name')
@click.argument('robot_id')
@click.option('--type', type=click.Choice(['mini', 'dedu', 'edu', 'kor']))
@click.option('--debug', is_flag=False)
def cli_show_py_pkg(pkg_name: str, robot_id: str, type: str = "dedu", debug: bool = True):
    from mini import query_py_pkg
    from mini import mini_sdk as MiniSdk
    if type == 'mini':
        MiniSdk.set_robot_type(MiniSdk.RobotType.MINI)
    elif type == 'dedu':
        MiniSdk.set_robot_type(MiniSdk.RobotType.DEDU)
    elif type == "edu":
        MiniSdk.set_robot_type(MiniSdk.RobotType.EDU)
    elif type == "kor":
        MiniSdk.set_robot_type(MiniSdk.RobotType.KOR)
    else:
        print(f'error robot_type:\'{type}\' param.')
        return
    if debug:
        import logging
        MiniSdk.set_log_level(logging.DEBUG)
    print(f'{query_py_pkg(pkg_name, robot_id)}')


@click.command()
@click.argument('robot_id')
@click.option('--type', type=click.Choice(['mini', 'dedu', 'edu', 'kor']))
@click.option('--debug', is_flag=False)
def cli_list_py_pkg(robot_id: str, type: str = "dedu", debug: bool = True):
    from mini import list_py_pkg
    from mini import mini_sdk as MiniSdk
    if type == 'mini':
        MiniSdk.set_robot_type(MiniSdk.RobotType.MINI)
    elif type == 'dedu':
        MiniSdk.set_robot_type(MiniSdk.RobotType.DEDU)
    elif type == "edu":
        MiniSdk.set_robot_type(MiniSdk.RobotType.EDU)
    elif type == "kor":
        MiniSdk.set_robot_type(MiniSdk.RobotType.KOR)
    else:
        print(f'error robot_type:\'{type}\' param.')
        return
    if debug:
        import logging
        MiniSdk.set_log_level(logging.DEBUG)
    print(f'{list_py_pkg(robot_id)}')


@click.command()
@click.argument('project_dir')
def cli_setup_py_pkg(project_dir: str):
    from mini import setup_py_pkg
    print(f'{setup_py_pkg(project_dir)}')


@click.command()
@click.option('--debug', is_flag=True)
@click.option('--type', type=click.Choice(['mini', 'dedu', 'edu', 'kor']))
@click.argument('pkg_path')
@click.argument('robot_id')
def cli_install_py_pkg(pkg_path: str, robot_id: str, type: str = "dedu", debug: bool = False):
    from mini import install_py_pkg
    from mini import mini_sdk as MiniSdk
    if type == 'mini':
        MiniSdk.set_robot_type(MiniSdk.RobotType.MINI)
    elif type == 'dedu':
        MiniSdk.set_robot_type(MiniSdk.RobotType.DEDU)
    elif type == "edu":
        MiniSdk.set_robot_type(MiniSdk.RobotType.EDU)
    elif type == "kor":
        MiniSdk.set_robot_type(MiniSdk.RobotType.KOR)
    else:
        print(f'error robot_type:\'{type}\' param.')
        return
    if debug:
        import logging
        MiniSdk.set_log_level(logging.DEBUG)
    install_py_pkg(pkg_path, robot_id, debug)


@click.command()
@click.option('--debug', is_flag=True)
@click.option('--type', type=click.Choice(['mini', 'dedu', 'edu', 'kor']))
@click.argument('pkg_name')
@click.argument('robot_id')
def cli_uninstall_py_pkg(pkg_name: str, robot_id: str, type: str = "dedu", debug: bool = False):
    from mini import uninstall_py_pkg
    from mini import mini_sdk as MiniSdk
    if type == 'mini':
        MiniSdk.set_robot_type(MiniSdk.RobotType.MINI)
    elif type == 'dedu':
        MiniSdk.set_robot_type(MiniSdk.RobotType.DEDU)
    elif type == "edu":
        MiniSdk.set_robot_type(MiniSdk.RobotType.EDU)
    elif type == "kor":
        MiniSdk.set_robot_type(MiniSdk.RobotType.KOR)
    else:
        print(f'error robot_type:\'{type}\' param.')
        return
    if debug:
        import logging
        MiniSdk.set_log_level(logging.DEBUG)
    uninstall_py_pkg(pkg_name, robot_id, debug)


@click.command()
@click.option('--debug', is_flag=True)
@click.option('--type', type=click.Choice(['mini', 'dedu', 'edu', 'kor']))
@click.argument('entry_point')
@click.argument('robot_id')
def cli_run_py_pkg(entry_point: str, robot_id: str, type: str = "dedu", debug: bool = False):
    from mini import run_py_pkg
    from mini import mini_sdk as MiniSdk
    if type == 'mini':
        MiniSdk.set_robot_type(MiniSdk.RobotType.MINI)
    elif type == 'dedu':
        MiniSdk.set_robot_type(MiniSdk.RobotType.DEDU)
    elif type == "edu":
        MiniSdk.set_robot_type(MiniSdk.RobotType.EDU)
    elif type == "kor":
        MiniSdk.set_robot_type(MiniSdk.RobotType.KOR)
    else:
        print(f'error robot_type:\'{type}\' param.')
        return
    if debug:
        import logging
        MiniSdk.set_log_level(logging.DEBUG)
    run_py_pkg(entry_point, robot_id, debug)


@click.command()
@click.option('--debug', is_flag=True)
@click.option('--type', type=click.Choice(['mini', 'dedu', 'edu', 'kor']))
@click.argument('cmd')
@click.argument('robot_id')
def cli_run_cmd(cmd: str, robot_id: str, type: str = "dedu", debug: bool = False):
    from mini import run_py_pkg
    from mini import mini_sdk as MiniSdk
    if type == 'mini':
        MiniSdk.set_robot_type(MiniSdk.RobotType.MINI)
    elif type == 'dedu':
        MiniSdk.set_robot_type(MiniSdk.RobotType.DEDU)
    elif type == "edu":
        MiniSdk.set_robot_type(MiniSdk.RobotType.EDU)
    elif type == "kor":
        MiniSdk.set_robot_type(MiniSdk.RobotType.KOR)
    else:
        print(f'error robot_type:\'{type}\' param.')
        return
    if debug:
        import logging
        MiniSdk.set_log_level(logging.DEBUG)
    run_py_pkg(cmd, robot_id, debug)


@click.command()
@click.option('--debug', is_flag=True)
@click.option('--type', type=click.Choice(['mini', 'dedu', 'edu', 'kor']))
@click.argument('cmd')
@click.argument('robot_id')
def cli_adb_enable(robot_id: str, type: str = "dedu", debug: bool = False):
    from mini import switch_adb
    from mini import mini_sdk as MiniSdk
    if type == 'mini':
        MiniSdk.set_robot_type(MiniSdk.RobotType.MINI)
    elif type == 'dedu':
        MiniSdk.set_robot_type(MiniSdk.RobotType.DEDU)
    elif type == "edu":
        MiniSdk.set_robot_type(MiniSdk.RobotType.EDU)
    elif type == "kor":
        MiniSdk.set_robot_type(MiniSdk.RobotType.KOR)
    else:
        print(f'error robot_type:\'{type}\' param.')
        return
    if debug:
        import logging
        MiniSdk.set_log_level(logging.DEBUG)
    switch_adb(robot_id, True)


@click.command()
@click.option('--debug', is_flag=True)
@click.option('--type', type=click.Choice(['mini', 'dedu', 'edu', 'kor']))
@click.argument('cmd')
@click.argument('robot_id')
def cli_adb_disable(robot_id: str, type: str = "dedu", debug: bool = False):
    from mini import switch_adb
    from mini import mini_sdk as MiniSdk
    if type == 'mini':
        MiniSdk.set_robot_type(MiniSdk.RobotType.MINI)
    elif type == 'dedu':
        MiniSdk.set_robot_type(MiniSdk.RobotType.DEDU)
    elif type == "edu":
        MiniSdk.set_robot_type(MiniSdk.RobotType.EDU)
    elif type == "kor":
        MiniSdk.set_robot_type(MiniSdk.RobotType.KOR)
    else:
        print(f'error robot_type:\'{type}\' param.')
        return
    if debug:
        import logging
        MiniSdk.set_log_level(logging.DEBUG)
    switch_adb(robot_id, False)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pccodemao_setrobotlanguage.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='pccodemao_setrobotlanguage.proto',
    package='packet',
    syntax='proto3',
    serialized_options=b'\n\034com.ubtrobot.pccodemao.protoB\020SetRobotLanguage',
    serialized_pb=b'\n pccodemao_setrobotlanguage.proto\x12\x06packet\"+\n\x17SetRobotLanguageRequest\x12\x10\n\x08language\x18\x01 \x01(\t\"\x8d\x01\n\x18SetRobotLanguageResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x12\x10\n\x08progress\x18\x03 \x01(\x03\x12\r\n\x05total\x18\x04 \x01(\x03\x12)\n\x05state\x18\x05 \x01(\x0e\x32\x1a.packet.SET_LANGUAGE_STATE*9\n\x12SET_LANGUAGE_STATE\x12\x08\n\x04\x46\x41IL\x10\x00\x12\x0c\n\x08\x44OWNLOAD\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x42\x30\n\x1c\x63om.ubtrobot.pccodemao.protoB\x10SetRobotLanguageb\x06proto3'
)

_SET_LANGUAGE_STATE = _descriptor.EnumDescriptor(
    name='SET_LANGUAGE_STATE',
    full_name='packet.SET_LANGUAGE_STATE',
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name='FAIL', index=0, number=0,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='DOWNLOAD', index=1, number=1,
            serialized_options=None,
            type=None),
        _descriptor.EnumValueDescriptor(
            name='SUCCESS', index=2, number=2,
            serialized_options=None,
            type=None),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=233,
    serialized_end=290,
)
_sym_db.RegisterEnumDescriptor(_SET_LANGUAGE_STATE)

SET_LANGUAGE_STATE = enum_type_wrapper.EnumTypeWrapper(_SET_LANGUAGE_STATE)
FAIL = 0
DOWNLOAD = 1
SUCCESS = 2

_SETROBOTLANGUAGEREQUEST = _descriptor.Descriptor(
    name='SetRobotLanguageRequest',
    full_name='packet.SetRobotLanguageRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='language', full_name='packet.SetRobotLanguageRequest.language', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=44,
    serialized_end=87,
)

_SETROBOTLANGUAGERESPONSE = _descriptor.Descriptor(
    name='SetRobotLanguageResponse',
    full_name='packet.SetRobotLanguageResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='packet.SetRobotLanguageResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='packet.SetRobotLanguageResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='progress', full_name='packet.SetRobotLanguageResponse.progress', index=2,
            number=3, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='total', full_name='packet.SetRobotLanguageResponse.total', index=3,
            number=4, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='state', full_name='packet.SetRobotLanguageResponse.state', index=4,
            number=5, type=14, cpp_type=8, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=90,
    serialized_end=231,
)

_SETROBOTLANGUAGERESPONSE.fields_by_name['state'].enum_type = _SET_LANGUAGE_STATE
DESCRIPTOR.message_types_by_name['SetRobotLanguageRequest'] = _SETROBOTLANGUAGEREQUEST
DESCRIPTOR.message_types_by_name['SetRobotLanguageResponse'] = _SETROBOTLANGUAGERESPONSE
DESCRIPTOR.enum_types_by_name['SET_LANGUAGE_STATE'] = _SET_LANGUAGE_STATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SetRobotLanguageRequest = _reflection.GeneratedProtocolMessageType('SetRobotLanguageRequest', (_message.Message,), {
    'DESCRIPTOR': _SETROBOTLANGUAGEREQUEST,
    '__module__': 'pccodemao_setrobotlanguage_pb2'
    # @@protoc_insertion_point(class_scope:packet.SetRobotLanguageRequest)
})
_sym_db.RegisterMessage(SetRobotLanguageRequest)

SetRobotLanguageResponse = _reflection.GeneratedProtocolMessageType('SetRobotLanguageResponse', (_message.Message,), {
    'DESCRIPTOR': _SETROBOTLANGUAGERESPONSE,
    '__module__': 'pccodemao_setrobotlanguage_pb2'
    # @@protoc_insertion_point(class_scope:packet.SetRobotLanguageResponse)
})
_sym_db.RegisterMessage(SetRobotLanguageResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import asyncio
import logging

import mini.mini_sdk as MiniSdk
from mini.dns.dns_browser import WiFiDevice


# 搜索指定序列号(在机器人屁股后面)的机器人, 可以只输入序列号尾部字符即可,长度任意, 建议5个字符以上可以准确匹配, 10秒超时
# 搜索的结果WiFiDevice, 包含机器人名称,ip,port等信息
async def test_get_device_by_name():
    """根据机器人序列号后缀搜索设备

    搜索指定序列号(在机器人屁股后面)的机器人, 可以只输入序列号尾部字符即可,长度任意, 建议5个字符以上可以准确匹配, 10秒超时


    Returns:
        WiFiDevice: 包含机器人名称,ip,port等信息

    """
    result: WiFiDevice = await MiniSdk.get_device_by_name("00038", 10)
    print(f"test_get_device_by_name result:{result}")
    return result


# 搜索指定序列号(在机器人屁股后面)的机器人,
async def test_get_device_list():
    """搜索所有设备

    搜索所有设备，10s后返回结果

    Returns:
        [WiFiDevice]: 所有搜索到的设备，WiFiDevice数组

    """
    results = await MiniSdk.get_device_list(10)
    print(f"test_get_device_list results = {results}")
    return results


# MiniSdk.connect 返回值为bool, 这里忽略返回值
async def test_connect(dev: WiFiDevice) -> bool:
    """连接设备

    连接指定的设备

    Args:
        dev (WiFiDevice): 指定的设备对象 WiFiDevice

    Returns:
        bool: 是否连接成功

    """
    return await MiniSdk.connect(dev)


# 进入编程模式,机器人有个tts播报,这里通过asyncio.sleep 让当前协程等6秒返回,让机器人播完
async def test_start_run_program():
    """进入编程模式demo

    使机器人进入编程模式，等待回复结果，并延时6秒，让机器人播完"进入编程模式"

    Returns:
        None:

    """
    await MiniSdk.enter_program()


# 断开连接并释放资源
async def shutdown():
    """断开连接并释放资源

    断开当前连接的设备，并释放资源

    """
    await MiniSdk.quit_program()
    await MiniSdk.release()


# 默认的日志级别是Warning, 设置为INFO
MiniSdk.set_log_level(logging.INFO)
# 设置机器人类型
MiniSdk.set_robot_type(MiniSdk.RobotType.DEDU)


async def main():
    device: WiFiDevice = await test_get_device_by_name()
    if device:
        await test_connect(device)
        await shutdown()


if __name__ == '__main__':
    asyncio.run(main())



#!/usr/bin/env python3

import enum


@enum.unique
class _PCProgramCmdId(enum.Enum):
    """
    pcCodeMao的命令号配置
    """

    RESPONSE_BASE = 1000

    PLAY_ACTION_REQUEST = 1
    """播放动作
    """

    MOVE_ROBOT_REQUEST = 2
    """移动机器人
    """

    STOP_ACTION_REQUEST = 3
    """停止动作
    """

    PLAY_TTS_REQUEST = 4
    """播放tts
    """

    FACE_DETECT_REQUEST = 5
    """人脸个数识别
    """

    FACE_ANALYSIS_REQUEST = 6
    """识别人脸 （男性 女性）
    """

    RECOGNISE_OBJECT_REQUEST = 7
    """物体 手势 花草识别
    """

    FACE_RECOGNISE_REQUEST = 8
    """识别到某人
    """

    TAKE_PICTURE_REQUEST = 9
    """拍照
    """

    PLAY_EXPRESSION_REQUEST = 10
    """播放表情
    """

    SET_MOUTH_LAMP_REQUEST = 11
    """设置嘴巴灯
    """

    SUBSCRIBE_INFRARED_DISTANCE_REQUEST = 12
    """订阅红外检测障碍物距离：监听
    """

    SUBSCRIBE_ROBOT_POSTURE_REQUEST = 13
    """订阅机器人姿态：监听
    """

    SUBSCRIBE_HEAD_RACKET_REQUEST = 14
    """订阅拍头事件：监听
    """

    CONTROL_BEHAVIOR_REQUEST = 15
    """控制行为
    """

    GET_ROBOT_VERSION_REQUEST = 16
    """获取版本号
    """
    GET_ROBOT_VERSION_RESPONSE = RESPONSE_BASE + GET_ROBOT_VERSION_REQUEST

    GET_INFRARED_DISTANCE_REQUEST = 19
    """获取红外距离
    """

    REVERT_ORIGIN_REQUEST = 20
    """停止所有操作
    """

    DISCONNECTION_REQUEST = 21
    """断开tcp
    """

    SWITCH_MOUTH_LAMP_REQUEST = 22
    """开关嘴巴灯
    """

    PLAY_AUDIO_REQUEST = 23
    """播放音效
    """

    STOP_AUDIO_REQUEST = 24
    """停止音效
    """

    GET_AUDIO_LIST_REQUEST = 25
    """获取音效列表
    """

    TRANSLATE_REQUEST = 26
    """翻译
    """

    WIKI_REQUEST = 27
    """百科
    """

    CHANGE_ROBOT_VOLUME_REQUEST = 28
    """改变机器人音量
    """

    PLAY_ONLINE_MUSIC_REQUEST = 29
    """播放在线音乐
    """

    FACE_DETECT_TASK_REQUEST = 30
    """人脸侦测任务(持续侦测)：监听
    """

    GET_REGISTER_FACES_REQUEST = 31
    """获取熟人列表
    """

    FACE_RECOGNISE_TASK_REQUEST = 32
    """人脸识别（持续识别）：监听
    """

    GET_ACTION_LIST = 33
    """获取机器人动作列表
    """

    CONTROL_ROBOT_AUDIO_RECORD = 34
    """控制机器人录音/播放/暂停等
    """

    SPEECH_RECOGNISE = 35
    """语音识别：监听
    """

    GET_SERVER_INFO = 36
    """获取服务器信息
    """

    PLAY_CUSTOM_ACTION_REQUEST = 37
    """播放自定义动作
    """

    STOP_CUSTOM_ACTION_REQUEST = 38
    """停止自定义动作
    """

    STOP_SPEECH_RECOGNISE_REQUEST = 39
    """停止语音识别
    """

    GET_ROBOT_LANGUAGE_MODE = 40
    """获取机器人语言模型
    """

    SET_ROBOT_LANGUAGE = 41
    """设置机器人语言
    """



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PyPi_RunWheel.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='PyPi_RunWheel.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\030com.ubtechinc.alpha.pypi',
  serialized_pb=b'\n\x13PyPi_RunWheel.proto\"3\n\x0fRunWheelRequest\x12\x11\n\twheelName\x18\x01 \x01(\t\x12\r\n\x05\x64\x65\x62ug\x18\x02 \x01(\x08\"7\n\x10RunWheelResponse\x12\x12\n\nresultCode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\tB\x1a\n\x18\x63om.ubtechinc.alpha.pypib\x06proto3'
)




_RUNWHEELREQUEST = _descriptor.Descriptor(
  name='RunWheelRequest',
  full_name='RunWheelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wheelName', full_name='RunWheelRequest.wheelName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debug', full_name='RunWheelRequest.debug', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23,
  serialized_end=74,
)


_RUNWHEELRESPONSE = _descriptor.Descriptor(
  name='RunWheelResponse',
  full_name='RunWheelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resultCode', full_name='RunWheelResponse.resultCode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='RunWheelResponse.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=131,
)

DESCRIPTOR.message_types_by_name['RunWheelRequest'] = _RUNWHEELREQUEST
DESCRIPTOR.message_types_by_name['RunWheelResponse'] = _RUNWHEELRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RunWheelRequest = _reflection.GeneratedProtocolMessageType('RunWheelRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNWHEELREQUEST,
  '__module__' : 'PyPi_RunWheel_pb2'
  # @@protoc_insertion_point(class_scope:RunWheelRequest)
  })
_sym_db.RegisterMessage(RunWheelRequest)

RunWheelResponse = _reflection.GeneratedProtocolMessageType('RunWheelResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNWHEELRESPONSE,
  '__module__' : 'PyPi_RunWheel_pb2'
  # @@protoc_insertion_point(class_scope:RunWheelResponse)
  })
_sym_db.RegisterMessage(RunWheelResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python3

import asyncio

from mini.apis.api_observe import ObserveFaceDetect, FaceDetectTaskResponse
from mini.apis.api_observe import ObserveFaceRecognise, FaceRecogniseTaskResponse
from mini.apis.api_observe import ObserveHeadRacket, ObserveHeadRacketResponse
from mini.apis.api_observe import ObserveInfraredDistance, ObserveInfraredDistanceResponse
from mini.apis.api_observe import ObserveRobotPosture, ObserveFallClimbResponse
from mini.apis.api_observe import ObserveSpeechRecognise, SpeechRecogniseResponse
from mini.dns.dns_browser import WiFiDevice
from test.test_connect import test_connect, shutdown
from test.test_connect import test_get_device_by_name, test_start_run_program


async def test_speech_recognise():
    """测试监听语音识别

    监听语音识别事件，校验识别是否成功，识别的结果文本是否有值，把结果存入result数组

    延时5s，结束函数，校验result中是否有值

    """
    result = []

    observer: ObserveSpeechRecognise = ObserveSpeechRecognise()

    def handler(msg):
        print(f"test_speech_recognise handle msg:{msg.text}")

        assert msg is not None and isinstance(msg, SpeechRecogniseResponse), "test_speech_recognise result not " \
                                                                             "available "
        assert msg.isSuccess, "test_speech_recognise failed"

        assert len(msg.text), "test_speech_recognise text is nothing"

        result.append(msg.text)

    observer.set_handler(handler)
    observer.start()

    await asyncio.sleep(10)

    print('---- stop ObserveSpeechRecognise')
    observer.stop()

    await asyncio.sleep(5)

    assert len(result), "test_speech_recognise result nil"


async def test_face_detect():
    """测试监听人脸个数

    监听人脸个数，校验成功结果，校验人脸个数大于0(需要有人脸在机器人面前)，把人脸个数结果存入result数组

    延时5s，结束函数，校验result数组是否有值

    """
    result = []

    observer: ObserveFaceDetect = ObserveFaceDetect()

    def handler(msg):
        print(f"test_face_detect handle msg:{msg}")

        assert msg is not None and isinstance(msg, FaceDetectTaskResponse), "test_face_detect result not " \
                                                                            "available "
        assert msg.isSuccess, "test_face_detect failed"

        assert msg.count, "test_face_detect count is 0"

        result.append(msg.count)

    observer.set_handler(handler)
    observer.start()

    await asyncio.sleep(10)

    print('---- stop ObserveFaceDetect')
    observer.stop()

    await asyncio.sleep(5)

    assert len(result), "test_face_detect result nil"


async def test_face_recognise():
    """测试监听人脸识别

    监听人脸识别事件，校验成功结果，校验识别到的人脸信息是否为空(需有人脸在机器人面前)，并把人脸信息存入result数组

    10s后结束监听

    延时5s，结束函数，校验result数组是否有值

    """
    result = []

    observer: ObserveFaceRecognise = ObserveFaceRecognise()

    def handler(msg):
        print(f"test_face_recognise handle msg:{msg}")

        assert msg is not None and isinstance(msg, FaceRecogniseTaskResponse), "test_face_recognise result not " \
                                                                               "available "
        assert msg.isSuccess, "test_face_recognise failed"

        assert msg.faceInfos is not None, "test_face_recognise faceInfos is nil"

        result.append(msg.faceInfos)

    observer.set_handler(handler)
    observer.start()

    await asyncio.sleep(10)

    print('---- stop ObserveFaceRecognise')
    observer.stop()

    await asyncio.sleep(5)

    assert len(result), "ObserveFaceRecognise result nil"


async def test_infrared_distance():
    """测试监听红外距离

    监听红外距离事件，校验结果distance是否有效(distance>0)，并存入result数组

    延时5s，结束函数，校验result数组是否有值

    Returns:

    """
    result = []

    observer: ObserveInfraredDistance = ObserveInfraredDistance()

    def handler(msg):
        print(f"test_infrared_distance handle msg:{msg}")

        assert msg is not None and isinstance(msg, ObserveInfraredDistanceResponse), "test_infrared_distance result " \
                                                                                     "not " \
                                                                                     "available "
        # assert msg.isSuccess, "test_infrared_distance failed"

        assert msg.distance is not None and msg.distance > 0, "test_infrared_distance distance unavailable"

        result.append(msg.distance)

    observer.set_handler(handler)
    observer.start()

    await asyncio.sleep(10)

    print('---- stop ObserveInfraredDistance')
    observer.stop()

    await asyncio.sleep(5)

    assert len(result), "ObserveInfraredDistance result nil"


async def test_robot_posture():
    """测试监听机器人姿态变化

    监听机器人姿态变化(需手动改变机器人姿态)，校验结果status是否有效(status>0)，并存入result数组

    延时5s，结束函数，并校验result数组是否有值

    Returns:

    """
    result = []

    observer: ObserveRobotPosture = ObserveRobotPosture()

    def handler(msg):
        print(f"test_robot_posture handle msg:{msg}")

        assert msg is not None and isinstance(msg, ObserveFallClimbResponse), "test_robot_posture result " \
                                                                              "not " \
                                                                              "available "
        # assert msg.isSuccess, "test_infrared_distance failed"

        assert msg.status is not None and msg.status > 0, "test_robot_posture status unavailable"

        result.append(msg.status)

    observer.set_handler(handler)
    observer.start()

    await asyncio.sleep(10)

    print('---- stop ObserveRobotPosture')
    observer.stop()

    await asyncio.sleep(5)

    assert len(result), "ObserveRobotPosture result nil"


async def test_head_racket():
    """测试监听拍头事件

    监听机器人拍头事件(需手动拍打机器人头部)，校验结果type是否有效(type>0)，并存入result数组

    延时5s，结束函数，并校验result数组是否有值

    Returns:

    """
    result = []

    observer: ObserveHeadRacket = ObserveHeadRacket()

    def handler(msg):
        print(f"test_head_racket handle msg:{msg}")

        assert msg is not None and isinstance(msg, ObserveHeadRacketResponse), "test_head_racket result " \
                                                                               "not " \
                                                                               "available "
        # assert msg.isSuccess, "test_infrared_distance failed"

        assert msg.type is not None and msg.type > 0, "test_head_racket type unavailable"

        result.append(msg.type)

    observer.set_handler(handler)
    observer.start()

    await asyncio.sleep(10)

    print('---- stop ObserveHeadRacket')
    observer.stop()

    await asyncio.sleep(5)

    assert len(result), "ObserveHeadRacket result nil"


async def main():
    device: WiFiDevice = await test_get_device_by_name()
    if device:
        await test_connect(device)
        await test_start_run_program()

        await test_speech_recognise()
        await test_face_detect()
        await test_face_recognise()
        await test_infrared_distance()
        await test_robot_posture()
        await test_head_racket()

        await shutdown()


if __name__ == '__main__':
    asyncio.run(main())



#!/usr/bin/env python3

import enum

from ..apis.base_api import BaseApi, DEFAULT_TIMEOUT
from ..apis.cmdid import _PCProgramCmdId
from ..pb2.codemao_controlbehavior_pb2 import ControlBehaviorRequest, ControlBehaviorResponse
from ..pb2.pccodemao_message_pb2 import Message


@enum.unique
class _RobotBehaviorControlType(enum.Enum):
    """
    表现力控制类型

    START(开始) : 开始舞蹈

    STOP(停止) : 停止舞蹈
    """
    START = 1  # 开始
    STOP = 0  # 停止


class StartBehavior(BaseApi):
    """开始舞蹈api

     控制机器人开始舞蹈

    Args:
        is_serial (bool): 是否等待回复，默认True
        name (str): 表现力名称，不可为空或None

    #ControlBehaviorResponse.isSuccess : 是否成功

    #ControlBehaviorResponse.resultCode : 返回码
    """

    def __init__(self, is_serial: bool = True, name: str = None):
        assert isinstance(name, str) and len(name), 'StartBehavior : name should be available'
        self.__is_serial = is_serial
        self.__name = name
        self.__event_type = _RobotBehaviorControlType.START.value

    async def execute(self):
        """
        执行开始舞蹈指令

        Returns:
            ControlBehaviorResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = ControlBehaviorRequest()
        request.name = self.__name
        request.eventType = self.__event_type

        cmd_id = _PCProgramCmdId.CONTROL_BEHAVIOR_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ControlBehaviorResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ControlBehaviorResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class StopBehavior(BaseApi):
    """停止舞蹈api

     控制机器人停止舞蹈

    Args:
        is_serial (bool): 是否等待回复，默认True

    #ControlBehaviorResponse.isSuccess : 是否成功

    #ControlBehaviorResponse.resultCode : 返回码
    """

    def __init__(self, is_serial: bool = True):
        self.__is_serial = is_serial
        self.__event_type = _RobotBehaviorControlType.START.value

    async def execute(self):
        """
        执行停止舞蹈指令

        Returns:
            ControlBehaviorResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = ControlBehaviorRequest()
        request.eventType = self.__event_type

        cmd_id = _PCProgramCmdId.CONTROL_BEHAVIOR_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            ControlBehaviorResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = ControlBehaviorResponse()
            response.ParseFromString(data)
            return response
        else:
            return None

# class _ControlBehavior(BaseApi):
#     """控制表现力api
#
#      控制机器人开始/停止舞蹈
#
#     Args:
#         is_serial (bool): 是否等待回复，默认True
#         name (str): 表现力名称，不可为空或None
#         control_type (RobotBehaviorControlType): 控制类型，默认START，表示开始执行
#
#     #ControlBehaviorResponse.isSuccess : 是否成功
#
#     #ControlBehaviorResponse.resultCode : 返回码
#     """
#
#     def __init__(self, is_serial: bool = True, name: str = None,
#                  control_type: RobotBehaviorControlType = RobotBehaviorControlType.START):
#         assert name is not None and len(name), 'ControlBehavior name should be available'
#         self.__isSerial = is_serial
#         self.__name = name
#         self.__eventType = control_type.value
#
#     async def execute(self):
#         """
#         执行表现力控制指令
#
#         Returns:
#             ControlBehaviorResponse
#         """
#         timeout = 0
#         if self.__isSerial:
#             timeout = DEFAULT_TIMEOUT
#
#         request = ControlBehaviorRequest()
#         request.name = self.__name
#         request.eventType = self.__eventType
#
#         cmd_id = _PCProgramCmdId.CONTROL_BEHAVIOR_REQUEST.value
#
#         return await self.send(cmd_id, request, timeout)
#
#     def _parse_msg(self, message):
#         """
#
#         Args:
#             message (Message):待解析的Message对象
#
#         Returns:
#             ControlBehaviorResponse
#         """
#         if isinstance(message, Message):
#             data = message.bodyData
#             response = ControlBehaviorResponse()
#             response.ParseFromString(data)
#             return response
#         else:
#             return None



import asyncio

from mini.apis import errors
from mini.apis.api_sence import FaceAnalysis, FaceAnalyzeResponse, StartSpeechRecognise
from mini.apis.api_sence import FaceDetect, FaceDetectResponse
from mini.apis.api_sence import FaceRecognise, FaceRecogniseResponse
from mini.apis.api_sence import GetInfraredDistance, GetInfraredDistanceResponse
from mini.apis.api_sence import GetRegisterFaces, GetRegisterFacesResponse
from mini.apis.api_sence import ObjectRecognise, RecogniseObjectResponse, ObjectRecogniseType
from mini.apis.api_sence import TakePicture, TakePictureResponse, TakePictureType
from mini.apis.base_api import MiniApiResultType
from mini.dns.dns_browser import WiFiDevice
from test.test_connect import test_connect, shutdown, test_start_run_program
from test.test_connect import test_get_device_by_name


# 测试人脸侦测
async def test_face_detect():
    """测试人脸个数侦测

    侦测人脸个数，10s超时，并等待回复结果

    #FaceDetectResponse.count : 人脸个数

    #FaceDetectResponse.isSuccess : 是否成功

    #FaceDetectResponse.resultCode : 返回码

    """
    # timeout: 指定侦测时长
    block: FaceDetect = FaceDetect(timeout=10)
    # response: FaceDetectResponse
    (resultType, response) = await block.execute()

    print(f'test_face_detect result: {response}')

    assert resultType == MiniApiResultType.Success, 'test_face_detect timetout'
    assert response is not None and isinstance(response, FaceDetectResponse), 'test_face_detect result unavailable'
    assert response.isSuccess, 'face_detect failed'


# 测试人脸分析(性别)
async def test_face_analysis():
    """测试人脸分析（性别）

    侦测人脸信息(性别、年龄)，超时时间10s，并等待回复结果

    当多人存在摄像头前时，返回占画面比例最大的那个人脸信息

    返回值：示例 {"age": 24, "gender": 99, "height": 238, "width": 238}

    age: 年龄

    gender：[1, 100], 小于50为女性，大于50为男性

    height：人脸在摄像头画面中的高度

    width：人脸在摄像头画面中的宽度

    """
    block: FaceAnalysis = FaceAnalysis(timeout=10)
    # response: FaceAnalyzeResponse
    (resultType, response) = await block.execute()

    print(f'test_face_analysis result: {response}')
    print('code = {0}, error={1}'.format(response.resultCode, errors.get_vision_error_str(response.resultCode)))

    assert resultType == MiniApiResultType.Success, 'test_face_analysis timetout'
    assert response is not None and isinstance(response, FaceAnalyzeResponse), 'test_face_analysis result unavailable'
    assert response.isSuccess, 'face_analysis failed'


# 测试物体识别：识别花，10s超时
async def test_object_recognise_flower():
    """测试物体(花)识别

    让机器人识别花(需手动把花或花的照片放到机器人面前)，超时10s，并等待结果

    #RecogniseObjectResponse.objects : 物体名数组[str]

    #RecogniseObjectResponse.isSuccess : 是否成功

    #RecogniseObjectResponse.resultCode : 返回码

    """
    # object_type: 支持FLOWER, FRUIT, GESTURE 三类物体
    block: ObjectRecognise = ObjectRecognise(object_type=ObjectRecogniseType.FLOWER, timeout=10)
    # response : RecogniseObjectResponse
    (resultType, response) = await block.execute()

    print(f'test_object_recognise_flower result: {response}')

    assert resultType == MiniApiResultType.Success, 'test_object_recognise_flower timetout'
    assert response is not None and isinstance(response,
                                               RecogniseObjectResponse), 'test_object_recognise_flower result unavailable'
    assert response.isSuccess, 'test_object_recognise_flower failed'


# 测试物体识别：识别水果，10s超时
async def test_object_recognise_fruit():
    """测试物体(水果)识别

    让机器人识别花(需手动把水果或水果的照片放到机器人面前)，超时10s，并等待结果

    #RecogniseObjectResponse.objects : 物体名数组[str]

    #RecogniseObjectResponse.isSuccess : 是否成功

    #RecogniseObjectResponse.resultCode : 返回码

    """
    # object_type: 支持FLOWER, FRUIT, GESTURE 三类物体
    block: ObjectRecognise = ObjectRecognise(object_type=ObjectRecogniseType.FRUIT, timeout=10)
    # response : RecogniseObjectResponse
    (resultType, response) = await block.execute()

    print(f'test_object_recognise_fruit result: {response}')

    assert resultType == MiniApiResultType.Success, 'test_object_recognise_fruit timetout'
    assert response is not None and isinstance(response,
                                               RecogniseObjectResponse), 'test_object_recognise_fruit result unavailable'
    assert response.isSuccess, 'test_object_recognise_fruit failed'


# 测试物体识别：识别手势，10s超时
async def test_object_recognise_gesture():
    """测试物体(手势)识别

    让机器人识别花(需手动在机器人面前作出手势)，超时10s，并等待结果

    #RecogniseObjectResponse.objects : 物体名数组[str]

    #RecogniseObjectResponse.isSuccess : 是否成功

    #RecogniseObjectResponse.resultCode : 返回码

    """
    # object_type: 支持FLOWER, FRUIT, GESTURE 三类物体
    block: ObjectRecognise = ObjectRecognise(object_type=ObjectRecogniseType.GESTURE, timeout=10)
    # response : RecogniseObjectResponse
    (resultType, response) = await block.execute()

    print(f'test_object_recognise_gesture result: {response}')

    assert resultType == MiniApiResultType.Success, 'test_object_recognise_gesture timetout'
    assert response is not None and isinstance(response,
                                               RecogniseObjectResponse), 'test_object_recognise_gesture result unavailable'
    assert response.isSuccess, 'test_object_recognise_gesture failed'


# 测试拍照
async def test_take_picture():
    """测试拍照

    让机器人立即拍照，并等待结果

    #TakePictureResponse.isSuccess : 是否成功

    #TakePictureResponse.code : 返回码

    #TakePictureResponse.picPath : 照片在机器人里的存储路径

    """
    # response: TakePictureResponse
    # take_picture_type: IMMEDIATELY-立即拍照, FINDFACE-找到人脸再拍照 两种拍照效果
    (resultType, response) = await TakePicture(take_picture_type=TakePictureType.IMMEDIATELY).execute()

    print(f'test_take_picture result: {response}')

    assert resultType == MiniApiResultType.Success, 'test_take_picture timetout'
    assert response is not None and isinstance(response, TakePictureResponse), 'test_take_picture result unavailable'
    assert response.isSuccess, 'test_take_picture failed'


# 测试人脸识别
async def test_face_recognise():
    """测试人脸识别

    让机器人进行人脸识别检测，超时10s，并等待结果


    #FaceRecogniseResponse.faceInfos : [FaceInfoResponse] 人脸信息数组

        FaceInfoResponse.id : 人脸id

        FaceInfoResponse.name : 姓名，如果是陌生人，则默认name为"stranger"

        FaceInfoResponse.gender : 性别

        FaceInfoResponse.age : 年龄

    #FaceRecogniseResponse.isSuccess : 是否成功

    #FaceRecogniseResponse.resultCode : 返回码

    Returns:

    """
    # response : FaceRecogniseResponse
    (resultType, response) = await FaceRecognise(timeout=10).execute()

    print(f'test_face_recognise result: {response}')

    assert resultType == MiniApiResultType.Success, 'test_face_recognise timetout'
    assert response is not None and isinstance(response,
                                               FaceRecogniseResponse), 'test_face_recognise result unavailable'
    assert response.isSuccess, 'test_face_recognise failed'


# 测试获取红外探测距离
async def test_get_infrared_distance():
    """测试红外距离检测

    获取当前机器人检测到的红外距离，并等待结果

    #GetInfraredDistanceResponse.distance : 红外距离

    """
    # response: GetInfraredDistanceResponse
    (resultType, response) = await GetInfraredDistance().execute()

    print(f'test_get_infrared_distance result: {response}')

    assert resultType == MiniApiResultType.Success, 'test_get_infrared_distance timetout'
    assert response is not None and isinstance(response,
                                               GetInfraredDistanceResponse), 'test_get_infrared_distance result unavailable'
    assert response.distance > 0, 'test_get_infrared_distance failed'


# 测试获取目前机器人内注册的人脸个数
async def test_get_register_faces():
    """测试获取已注册的人脸信息

    获取在机器人中已注册的所有人脸信息，并等待结果

    #GetRegisterFacesResponse.faceInfos : [FaceInfoResponse] 人脸信息数组

        #FaceInfoResponse.id : 人脸id

        #FaceInfoResponse.name : 姓名

        #FaceInfoResponse.gender : 性别

        #FaceInfoResponse.age : 年龄

    #GetRegisterFacesResponse.isSuccess : 是否成功

    #GetRegisterFacesResponse.resultCode : 返回码

    Returns:

    """
    # reponse : GetRegisterFacesResponse
    (resultType, response) = await GetRegisterFaces().execute()

    print(f'test_get_register_faces result: {response}')

    assert resultType == MiniApiResultType.Success, 'test_get_register_faces timetout'
    assert response is not None and isinstance(response,
                                               GetRegisterFacesResponse), 'test_get_register_faces result unavailable'
    assert response.isSuccess, 'test_get_register_faces failed'


async def test_speech_recognise_once():
    (resultType, response) = await StartSpeechRecognise(time_limit=20, asr_text="你好").execute()
    # block: StartSpeechRecognise = StartSpeechRecognise(time_limit=20, asr_text="你好")
    # response = await block.execute()
    print(f'speech_recognise: {response}')


async def main():
    device: WiFiDevice = await test_get_device_by_name()
    if device:
        await test_connect(device)
        await test_start_run_program()

        # await test_face_detect()
        # await test_face_analysis()
        # await test_take_picture()
        # await test_face_recognise()
        # await test_get_infrared_distance()
        # await test_get_register_faces()
        # await test_object_recognise_flower()
        # await test_object_recognise_fruit()
        # await test_object_recognise_gesture()
        await test_speech_recognise_once()

        await shutdown()


if __name__ == '__main__':
    asyncio.run(main())



import enum

from mini.apis.base_api import BaseApi, DEFAULT_TIMEOUT
from mini.apis.cmdid import _PCProgramCmdId
from mini.pb2.pccodemao_getrobotlanguage_pb2 import GetRobotLanguageRequest, GetRobotLanguageResponse
from ..pb2.pccodemao_message_pb2 import Message
from ..pb2.pccodemao_setrobotlanguage_pb2 import SetRobotLanguageRequest, SetRobotLanguageResponse


@enum.unique
class LanType(enum.Enum):
    """
    语言类型

    国家的缩写

    """
    CN = 0
    EN = 1
    TW = 2
    FR = 3
    DE = 4
    EL = 5
    JA = 6
    KO = 7
    RU = 8
    CS = 9
    DA = 10
    NL = 11
    FI = 12
    BN = 13
    AF = 14
    EU = 15
    BG = 16
    BE = 17
    EO = 18
    ID = 19
    IT = 20
    GA = 21
    KY = 22
    LA = 23
    LO = 24
    MS = 25
    NO = 26
    FA = 27
    PT = 28
    SR = 29
    SO = 30
    UZ = 31
    ZU = 32
    YO = 33
    VI = 34
    TH = 35
    TG = 36
    SK = 37
    AR = 38
    MN = 39
    MY = 40
    TL = 41


@enum.unique
class ServicePlatform(enum.Enum):
    """
    服务平台

    BAIDU : 百度

    TENCENT : 腾讯

    GOOGLE : 谷歌

    """
    BAIDU = 0
    TENCENT = 1
    GOOGLE = 2


class GetRobotLanguage(BaseApi):
    """获取机器人语言 api

    Returns:
            GetRobotLanguageResponse

    #GetRobotLanguageResponse.isSuccess

    #GetRobotLanguageResponse.resultCode

    #GetRobotLanguageResponse.language
    """

    def __init__(self, is_serial: bool = True):
        self.__isSerial = is_serial

    async def execute(self):
        """执行获取机器人语言

        Returns:
                GetRobotLanguageResponse

        #GetRobotLanguageResponse.isSuccess

        #GetRobotLanguageResponse.resultCode

        #GetRobotLanguageResponse.language
        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = GetRobotLanguageRequest()

        cmd_id = _PCProgramCmdId.GET_ROBOT_LANGUAGE_MODE.value

        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            GetRobotLanguageResponse

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = GetRobotLanguageResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class RobotLanguage(enum.Enum):
    """机器人支持的语言"""
    en_US = 0
    ru_RU = 1


class SetRobotLanguage(BaseApi):
    """设置机器人语言模型 api

    Returns:
            SetRobotLanguageResponse

    #SetRobotLanguageResponse.isSuccess

    #SetRobotLanguageResponse.resultCode

    #SetRobotLanguageResponse.progress

    #SetRobotLanguageResponse.total

    #SetRobotLanguageResponse.state
    """

    def __init__(self, is_serial: bool = True, language: RobotLanguage = RobotLanguage.en_US):
        assert isinstance(language, RobotLanguage), 'SetRobotLanguage : language should be #RobotLanguage# enum type'
        self.__is_serial: bool = is_serial
        self.__language: RobotLanguage = language

    async def execute(self):
        """执行设置机器人语言模型

        Returns:
            SetRobotLanguageResponse

        #SetRobotLanguageResponse.isSuccess

        #SetRobotLanguageResponse.resultCode

        #SetRobotLanguageResponse.progress

        #SetRobotLanguageResponse.total

        #SetRobotLanguageResponse.state
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = SetRobotLanguageRequest()
        request.language = self.__language.name

        cmd_id = _PCProgramCmdId.SET_ROBOT_LANGUAGE.value

        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            SetRobotLanguageResponse

        """
        if isinstance(message, Message):
            data = message.bodyData
            response = SetRobotLanguageResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



#!/usr/bin/env python3

import enum

from mini.pb2.codemao_speechrecognise_pb2 import SpeechRecogniseRequest, SpeechRecogniseResponse

from ..apis.base_api import BaseApi, DEFAULT_TIMEOUT
from ..apis.cmdid import _PCProgramCmdId
from ..pb2.codemao_faceanalyze_pb2 import FaceAnalyzeRequest, FaceAnalyzeResponse
from ..pb2.codemao_facedetect_pb2 import FaceDetectRequest, FaceDetectResponse
from ..pb2.codemao_facerecognise_pb2 import FaceRecogniseRequest, FaceRecogniseResponse
from ..pb2.codemao_getinfrareddistance_pb2 import GetInfraredDistanceRequest, GetInfraredDistanceResponse
from ..pb2.codemao_getregisterfaces_pb2 import GetRegisterFacesRequest, GetRegisterFacesResponse
from ..pb2.codemao_recogniseobject_pb2 import RecogniseObjectRequest, RecogniseObjectResponse
from ..pb2.codemao_takepicture_pb2 import TakePictureRequest, TakePictureResponse
from ..pb2.pccodemao_message_pb2 import Message


class FaceDetect(BaseApi):
    """检测人脸个数api

    Args:
        is_serial (bool): 是否等待回复，默认True
        timeout (int): 超时时间，必须大于0

    #FaceDetectResponse.count : 人脸个数

    #FaceDetectResponse.isSuccess : 是否成功

    #FaceDetectResponse.resultCode : 返回码

    #FaceDetectResponse.commandId

    """

    def __init__(self, is_serial: bool = True, timeout: int = 10):
        assert isinstance(timeout, int) and timeout > 0, 'FaceDetect : timeout should be positive'
        self.__is_serial = is_serial
        self.__timeout = timeout

    async def execute(self):
        """
        执行检测人脸个数指令

        Returns:
            FaceDetectResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = FaceDetectRequest()
        request.timeout = self.__timeout

        cmd_id = _PCProgramCmdId.FACE_DETECT_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            FaceDetectResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceDetectResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class FaceAnalysis(BaseApi):
    """人脸分析api

    通过人脸识别，分析性别、年龄

    当多人存在摄像头前时，返回脸面积最大的那个

    Args:
        is_serial (bool): 是否等待回复，默认True
        timeout (int): 超时时间

    返回示例:FaceAnalyzeResponse{"age":24,"gender":99,"height":238,"width":238}

    #FaceAnalyzeResponse.faceInfos : 人脸信息数组[FaceInfoResponse]

    #FaceInfoResponse.gender (int) :[0,100],小于50为女性，大于50为男性

    #FaceInfoResponse.age : 年龄

    #FaceInfoResponse.width : 人脸在摄像头画面中的宽度

    #FaceInfoResponse.height : 人脸在摄像头画面中的高度


    #FaceAnalyzeResponse.isSuccess : 是否成功

    #FaceAnalyzeResponse.resultCode : 返回码

    """

    def __init__(self, is_serial: bool = True, timeout: int = 10):
        assert isinstance(timeout, int) and timeout > 0, 'FaceAnalysis : timeout should be positive'
        self.__is_serial = is_serial
        self.__timeout = timeout

    async def execute(self):
        """
        执行人脸分析指令

        Returns:
            FaceAnalyzeResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT
        request = FaceAnalyzeRequest()
        request.timeout = self.__timeout

        cmd_id = _PCProgramCmdId.FACE_ANALYSIS_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            FaceAnalyzeResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceAnalyzeResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class ObjectRecogniseType(enum.Enum):
    """
    物体识别类型

    FRUIT : 水果

    GESTURE : 手势

    FLOWER : 花
    """
    FRUIT = 1  # 水果
    GESTURE = 2  # 手势
    FLOWER = 3  # 花


class ObjectRecognise(BaseApi):
    """物体识别api

    机器人通过摄像头识别相应的物体(水果/手势/花)

    Args:
        is_serial (bool): 是否等待回复，默认True
        object_type (ObjectRecogniseType): 物体识别类型，默认FRUIT，水果
        timeout (int): 超时时间

    #RecogniseObjectResponse.objects : 物体名数组[str]

    #RecogniseObjectResponse.isSuccess : 是否成功

    #RecogniseObjectResponse.resultCode : 返回码
    """

    def __init__(self, is_serial: bool = True, object_type: ObjectRecogniseType = ObjectRecogniseType.FRUIT,
                 timeout: int = 10):
        assert isinstance(timeout, int) and timeout > 0, 'ObjectRecognise : timeout should be positive'
        assert isinstance(object_type, ObjectRecogniseType), 'ObjectRecognise : objectType should be ' \
                                                             'ObjectRecogniseType instance '
        self.__is_serial = is_serial
        self.__object_type = object_type.value
        self.__timeout = timeout

    async def execute(self):
        """
        执行物体识别指令

        Returns:
            RecogniseObjectResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT

        request = RecogniseObjectRequest()
        request.objectType = self.__object_type
        request.timeout = self.__timeout

        cmd_id = _PCProgramCmdId.RECOGNISE_OBJECT_REQUEST.value

        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            RecogniseObjectResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = RecogniseObjectResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class FaceRecognise(BaseApi):
    """人脸识别api

    机器人通过摄像头识别出所有的人脸信息(熟人/陌生人)

    Args:
        is_serial (bool): 是否等待回复，默认True
        timeout (int): 超时时间

    #FaceRecogniseResponse.faceInfos([FaceInfoResponse]) : 人脸信息数组

    #FaceInfoResponse.id : 人脸id

    #FaceInfoResponse.name : 姓名，如果是陌生人，则默认name为"stranger"

    #FaceRecogniseResponse.isSuccess : 是否成功

    #FaceRecogniseResponse.resultCode : 返回码

    #FaceRecogniseResponse.commandId
    """

    def __init__(self, is_serial: bool = True, timeout: int = 10):
        assert isinstance(timeout, int) and timeout > 0, 'ObjectRecognise : timeout should be positive'
        self.__is_serial = is_serial
        self.__timeout = timeout

    async def execute(self):
        """
        执行人脸识别指令

        Returns:
            FaceRecogniseResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT
        request = FaceRecogniseRequest()
        request.timeout = self.__timeout

        cmd_id = _PCProgramCmdId.FACE_RECOGNISE_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            FaceRecogniseResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = FaceRecogniseResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


@enum.unique
class TakePictureType(enum.Enum):
    """
    拍照类型

    IMMEDIATELY : 立即拍照

    FINDFACE : 寻找人脸拍照
    """
    IMMEDIATELY = 0  # 立即拍照
    FINDFACE = 1  # 寻找人脸拍照


class TakePicture(BaseApi):
    """拍照api

    控制机器人拍照

    Args:
        is_serial (bool): 是否等待回复，默认True
        take_picture_type (TakePictureType): 拍照类型，默认IMMEDIATELY，立即拍照

    #TakePictureResponse.isSuccess : 是否成功

    #TakePictureResponse.code : 返回码

    #TakePictureResponse.picPath : 照片在机器人里的存储路径(sdcard/)
    """

    def __init__(self, is_serial: bool = True, take_picture_type: TakePictureType = TakePictureType.IMMEDIATELY):
        assert isinstance(take_picture_type, TakePictureType), 'TakePicture : take_picture_type should be ' \
                                                               'TakePictureType instance '
        self.__is_serial = is_serial
        self.__type = take_picture_type.value

    async def execute(self):
        """
        执行拍照指令

        Returns:
            TakePictureResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT
        request = TakePictureRequest()
        request.type = self.__type

        cmd_id = _PCProgramCmdId.TAKE_PICTURE_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            TakePictureResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = TakePictureResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class GetInfraredDistance(BaseApi):
    """获取红外距离api

    获取距离机器人正面最近的障碍物的红外距离

    Args:
        is_serial (bool): 是否等待回复，默认True

    #GetInfraredDistanceResponse.distance : 红外距离

    """

    def __init__(self, is_serial: bool = True):
        self.__is_serial = is_serial

    async def execute(self):
        """
        执行获取红外距离的指令

        Returns:
            GetInfraredDistanceResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT
        request = GetInfraredDistanceRequest()

        cmd_id = _PCProgramCmdId.GET_INFRARED_DISTANCE_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            GetInfraredDistanceResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = GetInfraredDistanceResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class GetRegisterFaces(BaseApi):
    """获取已注册的人脸列表api

    获取机器人中已注册的人脸列表数据

    Args:
        is_serial (bool): 是否等待回复，默认True

    #GetRegisterFacesResponse.faceInfos([FaceInfoResponse]) : 人脸信息数组

    #FaceInfoResponse.id : 人脸id

    #FaceInfoResponse.name : 姓名

    #GetRegisterFacesResponse.isSuccess : 是否成功

    #GetRegisterFacesResponse.resultCode : 返回码

    """

    def __init__(self, is_serial: bool = True):
        self.__is_serial = is_serial

    async def execute(self):
        """
        执行获取已注册人脸列表指令

        Returns:
            GetRegisterFacesResponse
        """
        timeout = 0
        if self.__is_serial:
            timeout = DEFAULT_TIMEOUT
        request = GetRegisterFacesRequest()

        cmd_id = _PCProgramCmdId.GET_REGISTER_FACES_REQUEST.value
        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            GetRegisterFacesResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = GetRegisterFacesResponse()
            response.ParseFromString(data)
            return response
        else:
            return None


class StartSpeechRecognise(BaseApi):
    """机器人语音识别Apiapi

    控制机器人开始录音

    Args:
        is_serial (bool): 是否等待回复，默认True
        time_limit (int): 录音时长，单位ms，默认60000ms，即60s

    #ControlRobotRecordResponse.isSuccess : 是否成功

    #ControlRobotRecordResponse.resultCode : 返回码

    #ControlRobotRecordResponse.id : 生成的录音文件名

    """

    def __init__(self, is_serial: bool = True, time_limit: int = 60000, asr_text: str = ""):
        assert isinstance(time_limit, int) and time_limit > 0, f'{self.__class__.__name__}  : time_limit should be ' \
                                                               f'positive '
        self.__isSerial = is_serial
        self.__timeLimit = time_limit
        self.__asrText = asr_text

    async def execute(self):
        """
        执行语音识别指令

        Returns:
            SpeechRecogniseResponse
        """
        timeout = 0
        if self.__isSerial:
            timeout = DEFAULT_TIMEOUT

        request = SpeechRecogniseRequest()
        request.timeLimit = self.__timeLimit
        request.asrText = self.__asrText
        cmd_id = _PCProgramCmdId.SPEECH_RECOGNISE.value

        return await self.send(cmd_id, request, timeout)

    def _parse_msg(self, message):
        """

        Args:
            message (Message):待解析的Message对象

        Returns:
            SpeechRecogniseResponse
        """
        if isinstance(message, Message):
            data = message.bodyData
            response = SpeechRecogniseResponse()
            response.ParseFromString(data)
            return response
        else:
            return None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PyPi_UploadScript.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='PyPi_UploadScript.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\030com.ubtechinc.alpha.pypi',
  serialized_pb=b'\n\x17PyPi_UploadScript.proto\"T\n\x0cUploadScript\x12\x10\n\x08\x66ileName\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x12\n\ncreateTime\x18\x03 \x01(\x03\x12\r\n\x05\x65xtra\x18\x04 \x01(\t\";\n\x14UploadScriptResponse\x12\x12\n\nresultCode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"@\n\x18ListUploadScriptResponse\x12$\n\ruploadScripts\x18\x01 \x03(\x0b\x32\r.UploadScriptB\x1a\n\x18\x63om.ubtechinc.alpha.pypib\x06proto3'
)




_UPLOADSCRIPT = _descriptor.Descriptor(
  name='UploadScript',
  full_name='UploadScript',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fileName', full_name='UploadScript.fileName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='UploadScript.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='createTime', full_name='UploadScript.createTime', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra', full_name='UploadScript.extra', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27,
  serialized_end=111,
)


_UPLOADSCRIPTRESPONSE = _descriptor.Descriptor(
  name='UploadScriptResponse',
  full_name='UploadScriptResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resultCode', full_name='UploadScriptResponse.resultCode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='UploadScriptResponse.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=172,
)


_LISTUPLOADSCRIPTRESPONSE = _descriptor.Descriptor(
  name='ListUploadScriptResponse',
  full_name='ListUploadScriptResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uploadScripts', full_name='ListUploadScriptResponse.uploadScripts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=238,
)

_LISTUPLOADSCRIPTRESPONSE.fields_by_name['uploadScripts'].message_type = _UPLOADSCRIPT
DESCRIPTOR.message_types_by_name['UploadScript'] = _UPLOADSCRIPT
DESCRIPTOR.message_types_by_name['UploadScriptResponse'] = _UPLOADSCRIPTRESPONSE
DESCRIPTOR.message_types_by_name['ListUploadScriptResponse'] = _LISTUPLOADSCRIPTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UploadScript = _reflection.GeneratedProtocolMessageType('UploadScript', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADSCRIPT,
  '__module__' : 'PyPi_UploadScript_pb2'
  # @@protoc_insertion_point(class_scope:UploadScript)
  })
_sym_db.RegisterMessage(UploadScript)

UploadScriptResponse = _reflection.GeneratedProtocolMessageType('UploadScriptResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADSCRIPTRESPONSE,
  '__module__' : 'PyPi_UploadScript_pb2'
  # @@protoc_insertion_point(class_scope:UploadScriptResponse)
  })
_sym_db.RegisterMessage(UploadScriptResponse)

ListUploadScriptResponse = _reflection.GeneratedProtocolMessageType('ListUploadScriptResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTUPLOADSCRIPTRESPONSE,
  '__module__' : 'PyPi_UploadScript_pb2'
  # @@protoc_insertion_point(class_scope:ListUploadScriptResponse)
  })
_sym_db.RegisterMessage(ListUploadScriptResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
